@@ -1,4 +1,3 @@
-static const char CVSID[] = "$Id: file.c,v 1.119 2008/11/05 09:09:44 lebert Exp $";
 /*******************************************************************************
 *									       *
 * file.c -- Nirvana Editor file i/o					       *
@@ -47,6 +46,7 @@ static const char CVSID[] = "$Id: file.c,v 1.119 2008/11/05 09:09:44 lebert Exp
 #include "../util/getfiles.h"
 #include "../util/printUtils.h"
 #include "../util/utils.h"
+#include "../util/nedit_malloc.h"
 
 #include <errno.h>
 #include <limits.h>
@@ -80,6 +80,8 @@ static const char CVSID[] = "$Id: file.c,v 1.119 2008/11/05 09:09:44 lebert Exp
 #include "../debug.h"
 #endif
 
+#include <inttypes.h>
+
 /* Maximum frequency in miliseconds of checking for external modifications.
    The periodic check is only performed on buffer modification, and the check
    interval is only to prevent checking on every keystroke in case of a file
@@ -486,7 +488,7 @@ static int doOpen(WindowInfo *window, const char *name, const char *path,
     fileLen = statbuf.st_size;
     
     /* Allocate space for the whole contents of the file (unfortunately) */
-    fileString = (char *)malloc(fileLen+1);  /* +1 = space for null */
+    fileString = (char *)NEditMalloc(fileLen+1);  /* +1 = space for null */
     if (fileString == NULL) {
         fclose(fp);
         window->filenameSet = FALSE; /* Temp. prevent check for changes. */
@@ -504,7 +506,7 @@ static int doOpen(WindowInfo *window, const char *name, const char *path,
         DialogF(DF_ERR, window->shell, 1, "Error while opening File",
                 "Error reading %s:\n%s", "OK", name, errorString());
         window->filenameSet = TRUE;
-        free(fileString);
+        NEditFree(fileString);
         return FALSE;
     }
     fileString[readLen] = 0;
@@ -571,7 +573,7 @@ static int doOpen(WindowInfo *window, const char *name, const char *path,
     }
 
     /* Release the memory that holds fileString */
-    free(fileString);
+    NEditFree(fileString);
 
     /* Set window title and file changed flag */
     if ((flags & PREF_READ_ONLY) != 0) {
@@ -626,7 +628,7 @@ int IncludeFile(WindowInfo *window, const char *name)
     fileLen = statbuf.st_size;
  
     /* allocate space for the whole contents of the file */
-    fileString = (char *)malloc(fileLen+1);  /* +1 = space for null */
+    fileString = (char *)NEditMalloc(fileLen+1);  /* +1 = space for null */
     if (fileString == NULL)
     {
         DialogF(DF_ERR, window->shell, 1, "Error opening File",
@@ -642,7 +644,7 @@ int IncludeFile(WindowInfo *window, const char *name)
         DialogF(DF_ERR, window->shell, 1, "Error opening File",
                 "Error reading %s:\n%s", "OK", name, errorString());
         fclose(fp);
-        free(fileString);
+        NEditFree(fileString);
         return FALSE;
     }
     fileString[readLen] = 0;
@@ -685,7 +687,7 @@ int IncludeFile(WindowInfo *window, const char *name)
     		fileString);
 
     /* release the memory that holds fileString */
-    free(fileString);
+    NEditFree(fileString);
 
     return TRUE;
 }
@@ -1030,7 +1032,7 @@ static int doSave(WindowInfo *window)
                 "%s not saved:\n%s", "OK", window->filename, errorString());
         fclose(fp);
         remove(fullname);
-        XtFree(fileString);
+        NEditFree(fileString);
         return FALSE;
     }
     
@@ -1039,12 +1041,12 @@ static int doSave(WindowInfo *window)
     {
         DialogF(DF_ERR, window->shell, 1, "Error closing File",
                 "Error closing file:\n%s", "OK", errorString());
-        XtFree(fileString);
+        NEditFree(fileString);
         return FALSE;
     }
 
     /* free the text buffer copy returned from XmTextGetString */
-    XtFree(fileString);
+    NEditFree(fileString);
     
 #ifdef VMS
     /* reflect the fact that NEdit is now editing a new version of the file */
@@ -1140,19 +1142,19 @@ int WriteBackupFile(WindowInfo *window)
                 errorString());
         fclose(fp);
         remove(name);
-        XtFree(fileString);
+        NEditFree(fileString);
         window->autoSave = FALSE;
         return FALSE;
     }
     
     /* close the backup file */
     if (fclose(fp) != 0) {
-	XtFree(fileString);
+	NEditFree(fileString);
 	return FALSE;
     }
 
     /* Free the text buffer copy returned from XmTextGetString */
-    XtFree(fileString);
+    NEditFree(fileString);
 
     return TRUE;
 }
@@ -1241,12 +1243,14 @@ static int writeBckVersion(WindowInfo *window)
        We preserve the normal permissions but not ownership, extended
        attributes, et cetera. */
     if (fstat(in_fd, &statbuf) != 0) {
+        close(in_fd);
 	return FALSE;
     }
 
     /* open the destination file exclusive and with restrictive permissions. */
     out_fd = open(bckname, O_CREAT|O_EXCL|O_TRUNC|O_WRONLY, S_IRUSR | S_IWUSR);
     if (out_fd < 0) {
+        close(in_fd);
         return bckError(window, "Error open backup file", bckname);
     }
 
@@ -1259,7 +1263,7 @@ static int writeBckVersion(WindowInfo *window)
     }
 
     /* Allocate I/O buffer */
-    io_buffer = (char*) malloc(IO_BUFFER_SIZE);
+    io_buffer = (char*) NEditMalloc(IO_BUFFER_SIZE);
     if (NULL == io_buffer) {
         close(in_fd);
         close(out_fd);
@@ -1363,7 +1367,7 @@ void PrintWindow(WindowInfo *window, int selectedOnly)
     PrintString(fileString, fileLen, window->shell, window->filename);
 
     /* Free the text buffer copy returned from XmTextGetString */
-    XtFree(fileString);
+    NEditFree(fileString);
 }
 
 /*
@@ -1457,7 +1461,7 @@ int PromptForExistingFile(WindowInfo *window, char *prompt, char *fullname)
     if (retVal != GFN_OK)
     	SetFileDialogDefaultDirectory(savedDefaultDir);
 
-    XtFree(savedDefaultDir);
+    NEditFree(savedDefaultDir);
 
     return retVal;
 }
@@ -1588,7 +1592,7 @@ int PromptForNewFile(WindowInfo *window, char *prompt, char *fullname,
     if (retVal != GFN_OK)
     	SetFileDialogDefaultDirectory(savedDefaultDir);
 
-    XtFree(savedDefaultDir);
+    NEditFree(savedDefaultDir);
 
     return retVal;
 }
@@ -1914,7 +1918,7 @@ static void setFormatCB(Widget w, XtPointer clientData, XtPointer callData)
     if (XmToggleButtonGetState(w)) {
         XtPointer userData;
         XtVaGetValues(w, XmNuserData, &userData, NULL);
-        *(int*) clientData = (int) userData;
+        *(int*) clientData = (int) (intptr_t) userData;
     }
 }
 
@@ -1974,7 +1978,7 @@ static void addWrapNewlines(WindowInfo *window)
     fileString = TextGetWrapped(window->textArea, 0,
     	    window->buffer->length, &fileLen);
     BufSetAll(window->buffer, fileString);
-    XtFree(fileString);
+    NEditFree(fileString);
 
     /* restore the insert and scroll positions of each pane */
     for (i=0; i<=window->nPanes; i++) {
