@@ -1,4 +1,3 @@
-static const char CVSID[] = "$Id: help.c,v 1.102 2004/08/01 10:06:10 yooden Exp $";
 /*******************************************************************************
 *                                                                              *
 * help.c -- Nirvana Editor help display                                        *
@@ -45,9 +44,11 @@ static const char CVSID[] = "$Id: help.c,v 1.102 2004/08/01 10:06:10 yooden Exp
 #include "help_data.h"
 #include "file.h"
 #include "highlight.h"
+#include "../util/motif.h"
 #include "../util/misc.h"
 #include "../util/DialogF.h"
 #include "../util/system.h"
+#include "../util/nedit_malloc.h"
 
 #include <locale.h>
 #include <stdlib.h>
@@ -111,11 +112,11 @@ static int LastSearchWasAllTopics = False;
 static enum helpFonts StyleFonts[] =
 {
     /* Fixed fonts, styles: 'A', 'B', 'C', 'D' */
-    FIXED_HELP_FONT, BOLD_FIXED_HELP_FONT, BOLD_FIXED_HELP_FONT,
+    FIXED_HELP_FONT, BOLD_FIXED_HELP_FONT, ITALIC_FIXED_HELP_FONT,
     BOLD_ITALIC_FIXED_HELP_FONT,
 
     /* Underlined fixed fonts, styles: 'E', 'F', 'G', 'H' */
-    FIXED_HELP_FONT, BOLD_FIXED_HELP_FONT, BOLD_FIXED_HELP_FONT,
+    FIXED_HELP_FONT, BOLD_FIXED_HELP_FONT, ITALIC_FIXED_HELP_FONT,
     BOLD_ITALIC_FIXED_HELP_FONT,
 
     /* Normal (proportional) fonts, styles: 'I', 'J', 'K', 'L' */
@@ -212,44 +213,42 @@ static char *bldInfoString = NULL;
 static void freeBuildInfo(void)
 {
     /* This keeps memory leak detectors happy */
-    XtFree(bldInfoString);
+    NEditFree(bldInfoString);
 }
 
+static const char *const warning =
+    "\nThis NEdit was built with a known-bad version of Motif.  Please "
+    "do not report any bugs you encounter unless you can reproduce "
+    "them with a known-good binary from the www.nedit.org website. "
+    "If this binary was supplied with your Linux distribution please "
+    "file a bug report with them asking them to build NEdit with a "
+    "known-good version of Motif.\n";
+
+
 static const char *getBuildInfo(void)
 {
-    const char * bldFormat =
+    static const char *bldFormat =
         "%s\n"
         "     Built on: %s, %s, %s\n"
         "     Built at: %s, %s\n"
-        "   With Motif: %d.%d.%d [%s]"
-#ifdef BUILD_BROKEN_NEDIT
-            " (KNOWN-BAD)\n"
-#elif defined BUILD_UNTESTED_NEDIT
-            " (UNTESTED)\n"
-#else 
-            "\n"
-#endif
+        "   With Motif: %s%d.%d.%d [%s]\n"
         "Running Motif: %d.%d [%s]\n"
         "       Server: %s %d\n"
         "       Visual: %s\n"
         "       Locale: %s\n"
-#ifdef BUILD_BROKEN_NEDIT
-        "\nThis NEdit was built with a known-bad version of Motif.  Please\n"
-        "do not report any bugs you encounter unless you can reproduce\n"
-        "them with a known-good binary from the www.nedit.org website.\n"
-        "If this binary was supplied with your Linux distribution please\n"
-        "file a bug report with them asking them to build NEdit with a\n"
-        "known-good version of Motif.\n"
-#endif
        ;
-    const char * visualClass[] = {"StaticGray",  "GrayScale",
-                                  "StaticColor", "PseudoColor",
-                                  "TrueColor",   "DirectColor"};
-    const char *locale;
+
+    static const char *visualClass[] = {"StaticGray",  "GrayScale",
+                                        "StaticColor", "PseudoColor",
+                                        "TrueColor",   "DirectColor"};
+
+    static const char *const stabilities[] = {"", "(Untested) ", "(Known Bad) "};
 
     if (bldInfoString == NULL)
     {
+        const char *locale;
         char visualStr[500] = "<unknown>";
+        const enum MotifStability stab = GetMotifStability();
 
         if (TheDisplay) {
             Visual     *visual;
@@ -265,21 +264,24 @@ static const char *getBuildInfo(void)
                     usingDefaultVisual ? ", Default" : "");
         }
 
-        bldInfoString = XtMalloc (strlen (bldFormat)  + 1024);
+        bldInfoString = (char*)NEditMalloc(strlen(bldFormat) + strlen(warning) + 1024);
         locale = setlocale(LC_MESSAGES, "");
 
         sprintf(bldInfoString, bldFormat,
-            NEditVersion,
-            COMPILE_OS, COMPILE_MACHINE, COMPILE_COMPILER,
-            linkdate, linktime,
-            XmVERSION, XmREVISION, XmUPDATE_LEVEL,
-            XmVERSION_STRING,
-            xmUseVersion/1000, xmUseVersion%1000,
-            _XmVersionString,
-            (NULL == TheDisplay ? "<unknown>" : ServerVendor(TheDisplay)),
-            (NULL == TheDisplay ? 0 : VendorRelease(TheDisplay)),
-            visualStr,
-            locale ? locale : "None");
+             NEditVersion,
+             COMPILE_OS, COMPILE_MACHINE, COMPILE_COMPILER,
+             linkdate, linktime,
+             stabilities[stab], XmVERSION, XmREVISION, XmUPDATE_LEVEL,
+             XmVERSION_STRING, 
+             xmUseVersion/1000, xmUseVersion%1000,
+             _XmVersionString,
+             (NULL == TheDisplay ? "<unknown>" : ServerVendor(TheDisplay)),
+             (NULL == TheDisplay ? 0 : VendorRelease(TheDisplay)),
+             visualStr,
+             locale ? locale : "None");
+
+        if (stab == MotifKnownBad)
+            strcat(bldInfoString, warning);
 
         atexit(freeBuildInfo);
     }
@@ -328,7 +330,7 @@ static void initHelpStyles (Widget parent)
             if (strstr (*line, "%s")  != NULL) 
             {
                 const char * bldInfo  = getBuildInfo();
-                char * text     = XtMalloc (strlen (*line)  + strlen (bldInfo));
+                char * text     = (char*)NEditMalloc(strlen (*line)  + strlen (bldInfo));
                 sprintf (text, *line, bldInfo);
                 *line = text;
                 break;
@@ -490,8 +492,8 @@ static char * stitch (
     * Get the needed space, one area for the help text being
     * stitched together, another for the styles to be applied.
     *--------------------------------------------------------*/
-    sp  = section   = XtMalloc (total_size +1);
-    sdp = styleData = (styleMap) ? XtMalloc (total_size +1)  : NULL;
+    sp  = section   = (char*)NEditMalloc(total_size +1);
+    sdp = styleData = (styleMap) ? (char*)NEditMalloc(total_size +1)  : NULL;
     *sp = EOS;
     
     /*--------------------------------------------
@@ -539,7 +541,7 @@ static char * stitch (
 void Help(enum HelpTopic topic)
 {
     if (HelpWindows[topic] != NULL)
-        RaiseShellWindow(HelpWindows[topic]);
+        RaiseShellWindow(HelpWindows[topic], True);
     else
         HelpWindows[topic] = createHelpPanel(topic);
     adaptNavigationButtons(topic);
@@ -551,7 +553,7 @@ static void setHelpWinTitle(Widget win, enum HelpTopic topic)
 {
     char * buf, *topStr=HelpTitles[topic];
     
-    buf=malloc(strlen(topStr) + 24);
+    buf=(char*)NEditMalloc(strlen(topStr) + 24);
     topic++; 
     
     sprintf(buf, "NEdit Help (%d)", (int)topic);
@@ -747,13 +749,13 @@ static Widget createHelpPanel(enum HelpTopic topic)
     
     /* Stuff the text into the widget's text buffer */
     BufSetAll (TextGetBuffer (HelpTextPanes[topic]) , helpText);
-    XtFree (helpText);
+    NEditFree(helpText);
     
     /* Create a style buffer for the text widget and fill it with the style
        data which was generated along with the text content */
     HelpStyleBuffers[topic] = BufCreate(); 
     BufSetAll(HelpStyleBuffers[topic], styleData);
-    XtFree (styleData);
+    NEditFree(styleData);
     TextDAttachHighlightData(((TextWidget)HelpTextPanes[topic])->text.textD,
             HelpStyleBuffers[topic], HelpStyleInfo, N_STYLES, '\0', NULL, NULL);
     
@@ -774,7 +776,7 @@ static Widget createHelpPanel(enum HelpTopic topic)
     XmProcessTraversal(HelpTextPanes[topic], XmTRAVERSE_CURRENT);
 
     /* Make close command in window menu gracefully prompt for close */
-    AddMotifCloseCallback(appShell, (XtCallbackProc)closeCB, appShell);
+    AddMotifCloseCallback(appShell, closeCB, appShell);
     
     /* Initialize navigation information, if it hasn't already been init'd */
     initNavigationHistory();
@@ -794,11 +796,11 @@ static Widget createHelpPanel(enum HelpTopic topic)
 static void changeTopicOrRaise(int existingTopic, int newTopic) {
     if(HelpWindows[newTopic] == NULL)
     {
-        changeWindowTopic(existingTopic, newTopic);
+        changeWindowTopic(existingTopic, (enum HelpTopic) newTopic);
         adaptNavigationButtons(newTopic);
     } else
     {
-        RaiseShellWindow(HelpWindows[newTopic]);
+        RaiseShellWindow(HelpWindows[newTopic], True);
         adaptNavigationButtons(existingTopic);
         adaptNavigationButtons(newTopic);
     }
@@ -918,7 +920,7 @@ static void printCB(Widget w, XtPointer clientData, XtPointer callData)
             TextGetBuffer(HelpTextPanes[topic])->length, &helpStringLen);
     PrintString(helpString, helpStringLen, HelpWindows[topic],
             HelpTitles[topic]);
-    XtFree(helpString);
+    NEditFree(helpString);
 }
 
 
@@ -984,15 +986,16 @@ static void followHyperlink(int topic, int charPosition, int newWindow)
     {
         if (HelpWindows[link_topic] != NULL)
         {
-            RaiseShellWindow(HelpWindows[link_topic]);
+            RaiseShellWindow(HelpWindows[link_topic], True);
         } else
         {
             if (newWindow)
             {
-                HelpWindows[link_topic] = createHelpPanel(link_topic);
+                HelpWindows[link_topic]
+                        = createHelpPanel((enum HelpTopic) link_topic);
             } else
             {
-                changeWindowTopic(topic, link_topic);
+                changeWindowTopic(topic, (enum HelpTopic) link_topic);
             }
         }
         navHistBack[link_topic] = topic;
@@ -1001,7 +1004,7 @@ static void followHyperlink(int topic, int charPosition, int newWindow)
         adaptNavigationButtons(link_topic);
         adaptNavigationButtons(topic);
     }
-    XtFree (link_text);
+    NEditFree(link_text);
 }
 
 static void helpFocusButtonsAP(Widget w, XEvent *event, String *args,
@@ -1177,10 +1180,10 @@ static void searchHelpText(Widget parent, int parentTopic,
                 &endMatch, NULL, NULL, GetPrefDelimiters()))
         {
             found = True;
-            XtFree(helpText);
+            NEditFree(helpText);
             break;
         }
-        XtFree(helpText);
+        NEditFree(helpText);
     }
 
     if (!found)
@@ -1209,7 +1212,8 @@ static void searchHelpText(Widget parent, int parentTopic,
     TextSetCursorPos(HelpTextPanes[topic], endMatch);
     
     /* Save the search information for search-again */
-    strcpy(LastSearchString, searchFor);
+    if (searchFor != LastSearchString) /* if srch-again avoid OSX overlap err */
+        strncpy(LastSearchString, searchFor, sizeof(LastSearchString)-1);
     LastSearchTopic = topic;
     LastSearchPos = endMatch;
     LastSearchWasAllTopics = allSections;
@@ -1245,9 +1249,9 @@ static void changeWindowTopic(int existingTopic, enum HelpTopic newTopic)
     TextDAttachHighlightData(((TextWidget)HelpTextPanes[newTopic])->text.textD,
             NULL, NULL, 0, '\0', NULL, NULL);
     BufSetAll(TextGetBuffer(HelpTextPanes[newTopic]), helpText);
-    XtFree(helpText);
+    NEditFree(helpText);
     BufSetAll(HelpStyleBuffers[newTopic], styleData);
-    XtFree(styleData);
+    NEditFree(styleData);
     TextDAttachHighlightData(((TextWidget)HelpTextPanes[newTopic])->text.textD,
             HelpStyleBuffers[newTopic], HelpStyleInfo, N_STYLES, '\0', NULL,
             NULL);
