@@ -1,4 +1,3 @@
-/* $Id: interpret.h,v 1.22 2008/10/03 14:34:55 lebert Exp $ */
 /*******************************************************************************
 *                                                                              *
 * interpret.h -- Nirvana Editor Interpreter Header File                        *
@@ -29,7 +28,7 @@
 #define NEDIT_INTERPRET_H_INCLUDED
 
 #include "nedit.h"
-#include "rbTree.h"
+#include "../util/rbTree.h"
 
 #define STACK_SIZE 1024		/* Maximum stack size */
 #define MAX_SYM_LEN 100 	/* Max. symbol name length */
