@@ -1,4 +1,3 @@
-static const char CVSID[] = "$Id: nc.c,v 1.48.2.2 2009/11/30 20:21:18 lebert Exp $";
 /*******************************************************************************
 *									       *
 * nc.c -- Nirvana Editor client program for nedit server processes	       *
@@ -503,7 +502,7 @@ static int startServer(const char *message, const char *commandLineArgs)
     
     /* prompt user whether to start server */
     if (!Preferences.autoStart) {
-	printf(message);
+	printf("%s", message);
 	do {
     	    c = getc(stdin);
 	} while (c == ' ' || c == '\t');
@@ -1002,7 +1001,7 @@ static void copyCommandLineArg(CommandLine *commandLine, const char *arg)
 /* Print version of 'nc' */
 static void printNcVersion(void ) {
    static const char *const ncHelpText = \
-   "nc (NEdit) Version 5.6 (November 2009)\n\n\
+   "nc (NEdit) Version 5.7 (January 2017)\n\n\
      Built on: %s, %s, %s\n\
      Built at: %s, %s\n";
      
