@@ -1,4 +1,3 @@
-static const char CVSID[] = "$Id: nedit.c,v 1.101 2012/10/25 14:10:25 tringali Exp $";
 /*******************************************************************************
 *									       *
 * nedit.c -- Nirvana Editor main program				       *
@@ -53,6 +52,7 @@ static const char CVSID[] = "$Id: nedit.c,v 1.101 2012/10/25 14:10:25 tringali E
 #include "../util/fileUtils.h"
 #include "../util/getfiles.h"
 #include "../util/motif.h"
+#include "../util/nedit_malloc.h"
 
 #include <ctype.h>
 #include <limits.h>
@@ -124,13 +124,13 @@ Widget TheAppShell;
    RedHat 7.3 won't default to '-1' for an encoding, if left with a *,
    and so reverts to "fixed".  Yech. */
 
-#define NEDIT_DEFAULT_FONT      "-*-helvetica-medium-r-normal-*-*-120-*-*-*-*-iso8859-1," \
-                                "-*-helvetica-bold-r-normal-*-*-120-*-*-*-*-iso8859-1=BOLD," \
-                                "-*-helvetica-medium-o-normal-*-*-120-*-*-*-*-iso8859-1=ITALIC"
+#define NEDIT_DEFAULT_FONT      "-*-helvetica-medium-r-normal-*-14-*-*-*-*-*-iso8859-1," \
+                                "-*-helvetica-bold-r-normal-*-14-*-*-*-*-*-iso8859-1=BOLD," \
+                                "-*-helvetica-medium-o-normal-*-14-*-*-*-*-*-iso8859-1=ITALIC"
 
-#define NEDIT_FIXED_FONT        "-*-courier-medium-r-normal-*-*-120-*-*-*-*-iso8859-1," \
-                                "-*-courier-bold-r-normal-*-*-120-*-*-*-*-iso8859-1=BOLD," \
-                                "-*-courier-medium-o-normal-*-*-120-*-*-*-*-iso8859-1=ITALIC"
+#define NEDIT_FIXED_FONT        "-*-courier-medium-r-normal-*-14-*-*-*-*-*-iso8859-1," \
+                                "-*-courier-bold-r-normal-*-14-*-*-*-*-*-iso8859-1=BOLD," \
+                                "-*-courier-medium-o-normal-*-14-*-*-*-*-*-iso8859-1=ITALIC"
 
 #define NEDIT_DEFAULT_BG        "#b3b3b3"
 
@@ -416,10 +416,15 @@ int main(int argc, char **argv)
 
     /* Warn user if this has been compiled wrong. */
     enum MotifStability stability = GetMotifStability();
+
     if (stability == MotifKnownBad) {
-        fputs("nedit: WARNING: This version of NEdit is built incorrectly, and will be unstable.\n"
-              "nedit: Please get a stable version of NEdit from http://www.nedit.org.\n",
+        fputs("nedit: WARNING: This version of NEdit is built incorrectly, and will be unstable.\n",
               stderr);
+#ifndef BUILD_BROKEN_NEDIT
+    /* Dear maintainers who are patching this; please have mercy on your users and link against 
+       a stable version of OpenMotif. */
+        exit(EXIT_FAILURE);
+#endif
     }
 
     /* Save the command which was used to invoke nedit for restart command */
@@ -845,14 +850,14 @@ static int checkDoMacroArg(const char *macro)
     /* Add a terminating newline (which command line users are likely to omit
        since they are typically invoking a single routine) */
     macroLen = strlen(macro);
-    tMacro = XtMalloc(strlen(macro)+2);
+    tMacro = (char*)NEditMalloc(strlen(macro)+2);
     strncpy(tMacro, macro, macroLen);
     tMacro[macroLen] = '\n';
     tMacro[macroLen+1] = '\0';
     
     /* Do a test parse */
     prog = ParseMacro(tMacro, &errMsg, &stoppedAt);
-    XtFree(tMacro);
+    NEditFree(tMacro);
     if (prog == NULL) {
     	ParseError(NULL, tMacro, stoppedAt, "argument to -do", errMsg);
 	return False;
@@ -1170,8 +1175,8 @@ static int virtKeyBindingsAreInvalid(const unsigned char* bindings)
     if (maxCount == 1) 
         return False; /* One binding is always ok */
     
-    keys = (char**)malloc(maxCount*sizeof(char*));
-    copy = XtNewString((const char*)bindings);
+    keys = (char**)NEditMalloc(maxCount*sizeof(char*));
+    copy = NEditStrdup((const char*)bindings);
     i = 0;
     pos2 = copy;
     
@@ -1203,7 +1208,7 @@ static int virtKeyBindingsAreInvalid(const unsigned char* bindings)
     if (count <= 1)
     {
        free(keys);
-       XtFree(copy);
+       NEditFree(copy);
        return False; /* No conflict */
     }
     
@@ -1215,12 +1220,12 @@ static int virtKeyBindingsAreInvalid(const unsigned char* bindings)
         {
             /* Duplicate detected */
             free(keys);
-            XtFree(copy);
+            NEditFree(copy);
             return True;
         }
     }
     free(keys);
-    XtFree(copy);
+    NEditFree(copy);
     return False;
 }
 
