@@ -1,4 +1,3 @@
-static const char CVSID[] = "$Id: regexConvert.c,v 1.4 2001/08/15 09:16:50 amai Exp $";
 /*------------------------------------------------------------------------*
  * `CompileRE', `ExecRE', and `ConvertSubstituteRE' -- regular expression parsing
  *
@@ -25,16 +24,42 @@ static const char CVSID[] = "$Id: regexConvert.c,v 1.4 2001/08/15 09:16:50 amai
  * | 3. Altered versions must be plainly marked as such, and must not  |
  * |      be misrepresented as being the original software.            |
  * `-------------------------------------------------------------------'
+ *
+ * This is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU General Public License as published by the Free Software
+ * Foundation; either version 2 of the License, or (at your option) any later
+ * version. In addition, you may distribute version of this program linked to
+ * Motif or Open Motif. See README for details.
+ *
+ * This software is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * for more details.
+ *
+ * You should have received a copy of the GNU General Public License along with
+ * software; if not, write to the Free Software Foundation, Inc., 59 Temple
+ * Place, Suite 330, Boston, MA  02111-1307 USA
+ *
  */
 
+#ifdef HAVE_CONFIG_H
+#include "../config.h"
+#endif
+
+#include "regexConvert.h"
+#include "../util/nedit_malloc.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
 #include <limits.h>
+
 #include <X11/Intrinsic.h>
 
-#include "regexConvert.h"
+#ifdef HAVE_DEBUG_H
+#include "../debug.h"
+#endif
 
 
 /* Utility definitions. */
@@ -98,7 +123,7 @@ static int            piece             (int *flag_param);
  * some of the structure of the compiled regexp.
  *----------------------------------------------------------------------*/
 
-char * ConvertRE (char *exp, char **errorText, char *cap_parens) {
+char * ConvertRE (const char *exp, char **errorText) {
 
    int  flags_local, pass;
 
@@ -138,7 +163,7 @@ char * ConvertRE (char *exp, char **errorText, char *cap_parens) {
          /* Allocate memory. */
 
          Convert_Str =
-            (unsigned char *) XtMalloc (sizeof (unsigned char) * Convert_Size);
+            (unsigned char *) NEditMalloc(sizeof (unsigned char) * Convert_Size);
 
          if (Convert_Str == NULL) {
             CONVERT_FAIL ("out of memory in `ConvertRE\'");
@@ -840,7 +865,7 @@ static unsigned char literal_escape (unsigned char c, int action) {
  *----------------------------------------------------------------------*/
 
 void ConvertSubstituteRE (
-   char   *source,
+   const char   *source,
    char   *dest,
    int     max) {
 
