@@ -1,4 +1,3 @@
-/* $Id: search.h,v 1.28 2006/10/13 07:26:02 ajbj Exp $ */
 /*******************************************************************************
 *                                                                              *
 * search.h -- Nirvana Editor Search Header File                                *
@@ -60,7 +59,7 @@ int ReplaceSame(WindowInfo *window, int direction, int searchWrap);
 int ReplaceAll(WindowInfo *window, const char *searchString, const char *replaceString,
 	int searchType);
 void ReplaceInSelection(const WindowInfo* window, const char* searchString,
-        const char* replaceString, const int searchType);
+        const char* replaceString, int searchType);
 int SearchWindow(WindowInfo *window, int direction, const char *searchString,
 	int searchType, int searchWrap, int beginPos, int *startPos, int *endPos, 
 	int *extentBW, int* extentFW);
