@@ -1,4 +1,3 @@
-static const char CVSID[] = "$Id: selection.c,v 1.31 2004/08/01 10:06:11 yooden Exp $";
 /*******************************************************************************
 *									       *
 * Copyright (C) 1999 Mark Edel						       *
@@ -40,6 +39,7 @@ static const char CVSID[] = "$Id: selection.c,v 1.31 2004/08/01 10:06:11 yooden
 #include "server.h"
 #include "../util/DialogF.h"
 #include "../util/fileUtils.h"
+#include "../util/nedit_malloc.h"
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -65,12 +65,12 @@ static const char CVSID[] = "$Id: selection.c,v 1.31 2004/08/01 10:06:11 yooden
 #endif
 
 
-static void gotoCB(Widget widget, WindowInfo *window, Atom *sel,
-	Atom *type, char *value, int *length, int *format);
-static void fileCB(Widget widget, WindowInfo *window, Atom *sel,
-	Atom *type, char *value, int *length, int *format);
-static void getAnySelectionCB(Widget widget, char **result, Atom *sel,
-	Atom *type, char *value, int *length, int *format);
+static void gotoCB(Widget widget, XtPointer window, Atom *sel,
+	Atom *type, XtPointer value, unsigned long *length, int *format);
+static void fileCB(Widget widget, XtPointer window, Atom *sel,
+	Atom *type, XtPointer value, unsigned long *length, int *format);
+static void getAnySelectionCB(Widget widget, XtPointer result, Atom *sel,
+	Atom *type, XtPointer value, unsigned long *length, int *format);
 static void processMarkEvent(Widget w, XtPointer clientData, XEvent *event,
     	Boolean *continueDispatch, char *action, int extend);
 static void markTimeoutProc(XtPointer clientData, XtIntervalId *id);
@@ -105,8 +105,9 @@ int StringToLineAndCol(const char *text, int *lineNum, int *column) {
     else                           { *lineNum = tempNum; }
 
     /* Find the next digit */
-    for ( textLen = strlen( endptr ); textLen > 0; endptr++, textLen-- ) {
-        if (isdigit((unsigned char) *endptr ) || *endptr == '-' || *endptr == '+') {
+    for ( textLen = strlen(endptr); textLen > 0; endptr++, textLen-- ) {
+        if (isdigit((unsigned char)*endptr) ||
+            *endptr == '-' || *endptr == '+') {
             break;
         }
     }
@@ -144,13 +145,13 @@ void GotoLineNumber(WindowInfo *window)
 void GotoSelectedLineNumber(WindowInfo *window, Time time)
 {
     XtGetSelectionValue(window->textArea, XA_PRIMARY, XA_STRING,
-    	    (XtSelectionCallbackProc)gotoCB, window, time);
+    	    gotoCB, window, time);
 }
 
 void OpenSelectedFile(WindowInfo *window, Time time)
 {
     XtGetSelectionValue(window->textArea, XA_PRIMARY, XA_STRING,
-    	    (XtSelectionCallbackProc)fileCB, window, time);
+    	    fileCB, window, time);
 }
 
 /*
@@ -174,7 +175,7 @@ char *GetAnySelection(WindowInfo *window)
     
     /* Request the selection value to be delivered to getAnySelectionCB */
     XtGetSelectionValue(window->textArea, XA_PRIMARY, XA_STRING,
-	    (XtSelectionCallbackProc)getAnySelectionCB, &selText, 
+	    getAnySelectionCB, &selText, 
 	    XtLastTimestampProcessed(XtDisplay(window->textArea)));
 
     /* Wait for the value to appear */
@@ -186,9 +187,12 @@ char *GetAnySelection(WindowInfo *window)
     return selText;
 }
 
-static void gotoCB(Widget widget, WindowInfo *window, Atom *sel,
-    	Atom *type, char *value, int *length, int *format)
+static void gotoCB(Widget widget, XtPointer wi, Atom *sel,
+    	Atom *type, XtPointer v, unsigned long *length, int *format)
 {
+    WindowInfo *window = wi;
+    char *value = v;
+    
      /* two integers and some space in between */
     char lineText[(TYPE_INT_STR_SIZE(int) * 2) + 5];
     int rc, lineNum, column, position, curCol;
@@ -200,21 +204,21 @@ static void gotoCB(Widget widget, WindowInfo *window, Atom *sel,
     }
     if (((size_t) *length) > sizeof(lineText) - 1) {
     	XBell(TheDisplay, 0);
-	XtFree(value);
+	NEditFree(value);
 	return;
     }
     /* should be of type text??? */
     if (*format != 8) {
     	fprintf(stderr, "NEdit: Can't handle non 8-bit text\n");
     	XBell(TheDisplay, 0);
-	XtFree(value);
+	NEditFree(value);
 	return;
     }
     strncpy(lineText, value, sizeof(lineText));
     lineText[sizeof(lineText) - 1] = '\0';
     
     rc = StringToLineAndCol(lineText, &lineNum, &column);
-    XtFree(value);
+    NEditFree(value);
     if (rc == -1) {
     	XBell(TheDisplay, 0);
 	return;
@@ -242,9 +246,12 @@ static void gotoCB(Widget widget, WindowInfo *window, Atom *sel,
     TextSetCursorPos(widget, position);
 }
 
-static void fileCB(Widget widget, WindowInfo *window, Atom *sel,
-    	Atom *type, char *value, int *length, int *format)
+static void fileCB(Widget widget, XtPointer wi, Atom *sel,
+    	Atom *type, XtPointer v, unsigned long *length, int *format)
 {
+    WindowInfo *window = wi;
+    char *value = v;
+
     char nameText[MAXPATHLEN], includeName[MAXPATHLEN];
     char filename[MAXPATHLEN], pathname[MAXPATHLEN];
     char *inPtr, *outPtr;
@@ -266,18 +273,18 @@ static void fileCB(Widget widget, WindowInfo *window, Atom *sel,
     }
     if (*length > MAXPATHLEN || *length == 0) {
     	XBell(TheDisplay, 0);
-	XtFree(value);
+	NEditFree(value);
 	return;
     }
     /* should be of type text??? */
     if (*format != 8) {
     	fprintf(stderr, "NEdit: Can't handle non 8-bit text\n");
     	XBell(TheDisplay, 0);
-	XtFree(value);
+	NEditFree(value);
 	return;
     }
     strncpy(nameText, value, *length);
-    XtFree(value);
+    NEditFree(value);
     nameText[*length] = '\0';
     
     /* extract name from #include syntax */
@@ -346,9 +353,9 @@ static void fileCB(Widget widget, WindowInfo *window, Atom *sel,
 	  }
       }
       for (i=0; i<nFiles; i++) {
-	   XtFree(nameList[i]);
+	   NEditFree(nameList[i]);
 	}
-      XtFree((char *)nameList);
+      NEditFree(nameList);
     }
 #else
     { glob_t globbuf;
@@ -369,22 +376,24 @@ static void fileCB(Widget widget, WindowInfo *window, Atom *sel,
     CheckCloseDim();
 }
 
-static void getAnySelectionCB(Widget widget, char **result, Atom *sel,
-	Atom *type, char *value, int *length, int *format)
+static void getAnySelectionCB(Widget widget, XtPointer voidresult, Atom *sel,
+	Atom *type, XtPointer voidvalue, unsigned long *length, int *format)
 {
+    char **result = voidresult;
+    char *value = voidvalue;
+    
     /* Confirm that the returned value is of the correct type */
     if (*type != XA_STRING || *format != 8) {
 	XBell(TheDisplay, 0);
-	if (value != NULL)
-	    XtFree((char *)value);
+        NEditFree(value);
 	*result = NULL;
 	return;
     }
 
     /* Append a null, and return the string */
-    *result = XtMalloc(*length + 1);
+    *result = (char*)NEditMalloc(*length + 1);
     strncpy(*result, value, *length);
-    XtFree(value);
+    NEditFree(value);
     (*result)[*length] = '\0';
 }
 
