@@ -1,4 +1,3 @@
-static const char CVSID[] = "$Id: shift.c,v 1.16 2004/07/21 11:32:05 yooden Exp $";
 /*******************************************************************************
 *									       *
 * shift.c -- Nirvana Editor built-in filter commands			       *
@@ -36,6 +35,7 @@ static const char CVSID[] = "$Id: shift.c,v 1.16 2004/07/21 11:32:05 yooden Exp
 #include "text.h"
 #include "nedit.h"
 #include "window.h"
+#include "../util/nedit_malloc.h"
 
 #include <string.h>
 #include <limits.h>
@@ -124,9 +124,9 @@ void ShiftSelection(WindowInfo *window, int direction, int byTab)
     	shiftDist = 1;
     shiftedText = ShiftText(text, direction, buf->useTabs, buf->tabDist,
     	    shiftDist, &shiftedLen);
-    XtFree(text);
+    NEditFree(text);
     BufReplaceSelected(buf, shiftedText);
-    XtFree(shiftedText);
+    NEditFree(shiftedText);
     
     newEndPos = selStart + shiftedLen;
     BufSelect(buf, selStart, newEndPos);
@@ -160,18 +160,16 @@ static void shiftRect(WindowInfo *window, int direction, int byTab,
     tempBuf->useTabs = buf->useTabs;
     text = BufGetRange(buf, selStart, selEnd);
     BufSetAll(tempBuf, text);
-    XtFree(text);
+    NEditFree(text);
     
     /* Do the shift in the temporary buffer */
     text = BufGetTextInRect(buf, selStart, selEnd, rectStart, rectEnd);
     BufRemoveRect(tempBuf, 0, selEnd-selStart, rectStart, rectEnd);
     BufInsertCol(tempBuf, rectStart+offset, 0, text, NULL, NULL);
-    XtFree(text);
+    NEditFree(text);
     
     /* Make the change in the real buffer */
-    text = BufGetAll(tempBuf);
-    BufReplace(buf, selStart, selEnd, text);
-    XtFree(text);
+    BufReplace(buf, selStart, selEnd, BufAsString(tempBuf));
     BufRectSelect(buf, selStart, selStart + tempBuf->length,
 	    rectStart+offset, rectEnd+offset);
     BufFree(tempBuf);
@@ -196,6 +194,7 @@ static void changeCase(WindowInfo *window, int makeUpper)
 {
     textBuffer *buf = window->buffer;
     char *text, *c;
+    char oldChar;
     int cursorPos, start, end, isRect, rectStart, rectEnd;
     
     /* Get the selection.  Use character before cursor if no selection */
@@ -211,12 +210,23 @@ static void changeCase(WindowInfo *window, int makeUpper)
 		tolower((unsigned char)*bufChar);
     	BufReplace(buf, cursorPos-1, cursorPos, bufChar);
     } else {
+        Boolean modified = False;
+
 	text = BufGetSelectionText(buf);
-	for (c=text; *c!='\0'; c++)
+        for (c = text; *c != '\0'; c++) {
+            oldChar = *c;
     	    *c = makeUpper ? toupper((unsigned char)*c) :
 		    tolower((unsigned char)*c);
-	BufReplaceSelected(buf, text);
-	XtFree(text);
+            if (*c != oldChar) {
+                modified = True;
+            }
+        }
+
+        if (modified) {
+            BufReplaceSelected(buf, text);
+        }
+
+	NEditFree(text);
 	if (isRect)
 	    BufRectSelect(buf, start, end, rectStart, rectEnd);
 	else
@@ -276,7 +286,7 @@ void FillSelection(WindowInfo *window)
     /* Fill the text */
     filledText = fillParagraphs(text, rightMargin, buf->tabDist, buf->useTabs,
 	    buf->nullSubsChar, &len, False);
-    XtFree(text);
+    NEditFree(text);
         
     /* Replace the text in the window */
     if (hasSelection && isRect) {
@@ -289,7 +299,7 @@ void FillSelection(WindowInfo *window)
 	if (hasSelection)
     	    BufSelect(buf, left, left + len);
     }
-    XtFree(filledText);
+    NEditFree(filledText);
     
     /* Find a reasonable cursor position.  Usually insertPos is best, but
        if the text was indented, positions can shift */
@@ -302,7 +312,7 @@ void FillSelection(WindowInfo *window)
 
 /*
 ** shift lines left and right in a multi-line text string.  Returns the
-** shifted text in memory that must be freed by the caller with XtFree.
+** shifted text in memory that must be freed by the caller with NEditFree.
 */
 char *ShiftText(char *text, int direction, int tabsAllowed, int tabDist,
 	int nChars, int *newLen)
@@ -320,7 +330,7 @@ char *ShiftText(char *text, int direction, int tabsAllowed, int tabDist,
         bufLen = strlen(text) + countLines(text) * nChars;
     else
         bufLen = strlen(text) + countLines(text) * tabDist;
-    shiftedText = (char *)XtMalloc(bufLen + 1);
+    shiftedText = (char*)NEditMalloc(bufLen + 1);
     
     /*
     ** break into lines and call shiftLine(Left/Right) on each
@@ -337,7 +347,7 @@ char *ShiftText(char *text, int direction, int tabsAllowed, int tabDist,
 			nChars);
 	    strcpy(shiftedPtr, shiftedLine);
 	    shiftedPtr += strlen(shiftedLine);
-	    XtFree(shiftedLine);
+	    NEditFree(shiftedLine);
 	    if (*textPtr == '\0') {
 	        /* terminate string & exit loop at end of text */
 	    	*shiftedPtr = '\0';
@@ -363,7 +373,7 @@ static char *shiftLineRight(char *line, int lineLen, int tabsAllowed,
     int whiteWidth, i;
     
     lineInPtr = line;
-    lineOut = XtMalloc(lineLen + nChars + 1);
+    lineOut = (char*)NEditMalloc(lineLen + nChars + 1);
     lineOutPtr = lineOut;
     whiteWidth = 0;
     while (TRUE) {
@@ -406,7 +416,7 @@ static char *shiftLineLeft(char *line, int lineLen, int tabDist, int nChars)
     char *lineInPtr, *lineOutPtr;
     
     lineInPtr = line;
-    lineOut = XtMalloc(lineLen + tabDist + 1);
+    lineOut = (char*)NEditMalloc(lineLen + tabDist + 1);
     lineOutPtr = lineOut;
     whiteWidth = 0;
     lastWhiteWidth = 0;
@@ -573,11 +583,11 @@ static char *fillParagraphs(char *text, int rightMargin, int tabDist,
 	/* Fill the paragraph */
 	filledText = fillParagraph(paraText, leftMargin, firstLineIndent,
 		rightMargin, tabDist, useTabs, nullSubsChar, &len);
-	XtFree(paraText);
+	NEditFree(paraText);
 	
 	/* Replace it in the buffer */
 	BufReplace(buf, paraStart, fillEnd, filledText);
-	XtFree(filledText);
+	NEditFree(filledText);
 	
 	/* move on to the next paragraph */
 	paraStart += len;
@@ -606,7 +616,7 @@ static char *fillParagraph(char *text, int leftMargin, int firstLineIndent,
     int inWhitespace, inMargin;
     
     /* remove leading spaces, convert newlines to spaces */
-    cleanedText = XtMalloc(strlen(text)+1);
+    cleanedText = (char*)NEditMalloc(strlen(text)+1);
     outPtr = cleanedText;
     inMargin = True;
     for (c=text; *c!='\0'; c++) {
@@ -666,7 +676,7 @@ static char *fillParagraph(char *text, int leftMargin, int firstLineIndent,
     indentString = makeIndentString(leftMargin, tabDist, allowTabs, &indentLen);
         
     /* allocate memory for the finished string */
-    outText = XtMalloc(sizeof(char) * (cleanedLen + leadIndentLen +
+    outText = (char*)NEditMalloc(sizeof(char) * (cleanedLen + leadIndentLen +
 	    indentLen * (nLines-1) + 1));
     outPtr = outText;
     
@@ -687,9 +697,9 @@ static char *fillParagraph(char *text, int leftMargin, int firstLineIndent,
     *outPtr = '\0';
     
     /* clean up, return result */
-    XtFree(cleanedText);
-    XtFree(leadIndentStr);
-    XtFree(indentString);
+    NEditFree(cleanedText);
+    NEditFree(leadIndentStr);
+    NEditFree(indentString);
     *filledLen = outPtr - outText;
     return outText;
 }
@@ -699,7 +709,7 @@ static char *makeIndentString(int indent, int tabDist, int allowTabs, int *nChar
     char *indentString, *outPtr;
     int i;
     
-    outPtr = indentString = XtMalloc(sizeof(char) * indent + 1);
+    outPtr = indentString = (char*)NEditMalloc(sizeof(char) * indent + 1);
     if (allowTabs) {
 	for (i=0; i<indent/tabDist; i++)
     	    *outPtr++ = '\t';
