@@ -1,4 +1,3 @@
-static const char CVSID[] = "$Id: tags.c,v 1.71 2009/06/23 21:30:09 lebert Exp $";
 /*******************************************************************************
 *                                                                              *
 * tags.c -- Nirvana editor tag file handling                                   *
@@ -45,6 +44,8 @@ static const char CVSID[] = "$Id: tags.c,v 1.71 2009/06/23 21:30:09 lebert Exp $
 #include "../util/fileUtils.h"
 #include "../util/misc.h"
 #include "../util/utils.h"
+#include "../util/refString.h"
+#include "../util/nedit_malloc.h"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -79,16 +80,16 @@ static const char CVSID[] = "$Id: tags.c,v 1.71 2009/06/23 21:30:09 lebert Exp $
    (should probably be a language-dependent option, but...) */
 #define TIP_DEFAULT_LINES 4
 
-#define STRSAVE(a)  ((a!=NULL)?strcpy(malloc(strlen(a)+1),(a)):strcpy(malloc(1),""))
+#define STRSAVE(a)  (NEditStrdup(a!=NULL?a:""))
 
 typedef struct _tag {
     struct _tag *next;
     const char *path;
     const char *name;
     const char *file;
-    int language;
     const char *searchString; /* see comment below */
     int posInf;               /* see comment below */
+    short language;
     short index;
 } tag;
 
@@ -102,14 +103,13 @@ typedef struct _tag {
 enum searchDirection {FORWARD, BACKWARD};
 
 static int loadTagsFile(const char *tagSpec, int index, int recLevel);
-static void findDefCB(Widget widget, WindowInfo *window, Atom *sel,
-        Atom *type, char *value, int *length, int *format);
+static void findDefCB(Widget widget, XtPointer closure, Atom *sel,
+        Atom *type, XtPointer value, unsigned long *length, int *format);
 static void setTag(tag *t, const char *name, const char *file,
                    int language, const char *searchString, int posInf, 
                    const char * tag);
 static int fakeRegExSearch(WindowInfo *window, char *buffer, 
                         const char *searchString, int *startPos, int *endPos);
-static unsigned hashAddr(const char *key);
 static void updateMenuItems(void);
 static int addTag(const char *name, const char *file, int lang, 
                     const char *search, int posInf,  const  char *path, 
@@ -125,8 +125,6 @@ static Widget createSelectMenu(Widget parent, char *label, int nArgs,
 static void editTaggedLocation( Widget parent, int i );
 static void showMatchingCalltip( Widget parent, int i );
 
-static const char *rcs_strdup(const char *str);
-static void rcs_free(const char *str);
 static int searchLine(char *line, const char *regex);
 static void rstrip( char *dst, const char *src );
 static int nextTFBlock(FILE *fp, char *header, char **tiptext, int *lineAt, 
@@ -136,7 +134,7 @@ static int loadTipsFile(const char *tipsFile, int index, int recLevel);
 /* Hash table of tags, implemented as an array.  Each bin contains a 
     NULL-terminated linked list of parsed tags */
 static tag **Tags = NULL;
-static int DefTagHashSize = 10000;
+static unsigned DefTagHashSize = 100000u;
 /* list of loaded tags files */
 tagFile *TagsFileList = NULL;
 
@@ -177,29 +175,11 @@ static tagFile *setFileListHead(tagFile *t, int file_type )
     return t;
 }
 
-/*      Compute hash address from a string key */
-static unsigned hashAddr(const char *key)
-{
-    unsigned s=strlen(key);
-    unsigned a=0,x=0,i;
-    
-    for (i=0; (i+3)<s; i += 4) {
-        strncpy((char*)&a,&key[i],4);
-        x += a;
-    }
-    
-    for (a=1; i<(s+1); i++, a *= 256)
-        x += key[i] * a;
-        
-    return x;
-}
-
 /*      Retrieve a tag structure from the hash table */
 static tag *getTag(const char *name, int search_type)
 {
     static char lastName[MAXLINE];
-    static tag *t;
-    static int addr;
+    static tag *t = NULL;
     tag **table;
     
     if (search_type == TIP)
@@ -210,7 +190,7 @@ static tag *getTag(const char *name, int search_type)
     if (table == NULL) return NULL;
     
     if (name) {
-        addr = hashAddr(name) % DefTagHashSize;
+        unsigned const addr = StringHashAddr(name) % DefTagHashSize;
         t = table[addr];
         strcpy(lastName,name);
     }
@@ -225,6 +205,22 @@ static tag *getTag(const char *name, int search_type)
     return NULL;
 }
 
+/*
+** Searches for `tpl` tag in the list `bkt`
+*/
+static tag* matchTagRec(tag const* tpl, tag* bkt)
+{
+    /* pointers comparison can be used instead of strcmp because strings
+       are made shared by setTag() */
+    tag *t = bkt;
+    for (; t; t = t->next)
+        if ((tpl->language == t->language) && (tpl->posInf == t->posInf) &&
+            (tpl->name == t->name) && (tpl->searchString == t->searchString) &&
+            (tpl->file == t->file)) return t;
+
+    return NULL;
+}
+
 /* Add a tag specification to the hash table 
 **   Return Value:  0 ... tag already existing, spec not added
 **                  1 ... tag spec is new, added.
@@ -234,48 +230,46 @@ static tag *getTag(const char *name, int search_type)
 static int addTag(const char *name, const char *file, int lang, 
                     const char *search, int posInf, const char *path, int index)
 {
-    int addr = hashAddr(name) % DefTagHashSize;
-    tag *t;
     char newfile[MAXPATHLEN];
     tag **table;
 
     if (searchMode == TIP) {
         if (Tips == NULL) 
-            Tips = (tag **)calloc(DefTagHashSize, sizeof(tag*));
+            Tips = (tag **)NEditCalloc(DefTagHashSize, sizeof(tag*));
         table = Tips;
     } else {
         if (Tags == NULL) 
-            Tags = (tag **)calloc(DefTagHashSize, sizeof(tag*));
+            Tags = (tag **)NEditCalloc(DefTagHashSize, sizeof(tag*));
         table = Tags;
     }
-    
+
     if (*file == '/')
-        strcpy(newfile,file);
+        strncpy(newfile, file, MAXPATHLEN);
     else
-        sprintf(newfile,"%s%s", path, file);
-    
+        snprintf(newfile, MAXPATHLEN, "%s%s", path, file);
+    newfile[MAXPATHLEN - 1] = '\0';
+
     NormalizePathname(newfile);
-        
-    for (t = table[addr]; t; t = t->next) {
-        if (strcmp(name,t->name)) continue;
-        if (lang != t->language) continue;
-        if (strcmp(search,t->searchString)) continue;
-        if (posInf != t->posInf) continue;
-        if (*t->file == '/' && strcmp(newfile,t->file)) continue;
-        if (*t->file != '/') {
-            char tmpfile[MAXPATHLEN];
-            sprintf(tmpfile, "%s%s", t->path, t->file);
-            NormalizePathname(tmpfile);
-            if (strcmp(newfile, tmpfile)) continue;
+
+    {
+        tag tpl;
+        setTag(&tpl, name, newfile, lang, search, posInf, path);
+
+        {
+            unsigned const addr = StringHashAddr(tpl.name) % DefTagHashSize;
+
+            tag *t = matchTagRec(&tpl, table[addr]);
+            if (t)
+                return 0;
+
+            t = NEditNew(tag);
+            *t = tpl;
+            t->index = index;
+            t->next = table[addr];
+            table[addr] = t;
         }
-        return 0;
     }
-        
-    t = (tag *) malloc(sizeof(tag));
-    setTag(t, name, file, lang, search, posInf, path);
-    t->index = index;
-    t->next = table[addr];
-    table[addr] = t;
+
     return 1;
 }
 
@@ -300,28 +294,31 @@ static int delTag(const char *name, const char *file, int lang,
         
     if (table == NULL) return FALSE;
     if (name)
-        start = finish = hashAddr(name) % DefTagHashSize;
+        start = finish = StringHashAddr(name) % DefTagHashSize;
     else {
         start = 0;
         finish = DefTagHashSize;
     }
+
     for (i = start; i<finish; i++) {
         for (last = NULL, t = table[i]; t; last = t, t = t?t->next:table[i]) {
-            if (name && strcmp(name,t->name)) continue;
             if (index && index != t->index) continue;
-            if (file && strcmp(file,t->file)) continue;
+            if (posInf != t->posInf) continue;
             if (lang >= PLAIN_LANGUAGE_MODE && lang != t->language) continue;
+            if (name && strcmp(name,t->name)) continue;
+            if (file && strcmp(file,t->file)) continue;
             if (search && strcmp(search,t->searchString)) continue;
-            if (posInf == t->posInf) continue;
+
             if (last)
                 last->next = t->next;
             else
                 table[i] = t->next;
-            rcs_free(t->name);
-            rcs_free(t->file);
-            rcs_free(t->searchString);
-            rcs_free(t->path);
-            free(t);
+
+            RefStringFree(t->name);
+            RefStringFree(t->file);
+            RefStringFree(t->searchString);
+            RefStringFree(t->path);
+            NEditFree(t);
             t = NULL;
             del++;
         }
@@ -353,8 +350,7 @@ int AddRelTagsFile(const char *tagSpec, const char *windowPath, int file_type)
     else
         FileList = TipsFileList;
 
-    tmptagSpec = (char *) malloc(strlen(tagSpec)+1);
-    strcpy(tmptagSpec, tagSpec);
+    tmptagSpec = NEditStrdup(tagSpec);
     for (filename = strtok(tmptagSpec, ":"); filename; filename = strtok(NULL, ":")){
         if (*filename == '/' || *filename == '~')
             continue;
@@ -374,7 +370,7 @@ int AddRelTagsFile(const char *tagSpec, const char *windowPath, int file_type)
         }
         if (stat(pathName, &statbuf) != 0)
             continue;
-        t = (tagFile *) malloc(sizeof(tagFile));
+        t = (tagFile *) NEditMalloc(sizeof(tagFile));
         t->filename = STRSAVE(pathName);
         t->loaded = 0;
         t->date = statbuf.st_mtime;
@@ -383,7 +379,7 @@ int AddRelTagsFile(const char *tagSpec, const char *windowPath, int file_type)
         FileList = setFileListHead(t, file_type);
         added=1;
     }
-    free(tmptagSpec);
+    NEditFree(tmptagSpec);
     updateMenuItems();
     if (added)
         return TRUE;
@@ -423,8 +419,7 @@ int AddTagsFile(const char *tagSpec, int file_type)
     else
         FileList = TipsFileList;
 
-    tmptagSpec = (char *) malloc(strlen(tagSpec)+1);
-    strcpy(tmptagSpec, tagSpec);    
+    tmptagSpec = NEditStrdup(tagSpec);
     for (filename = strtok(tmptagSpec,":"); filename; filename = strtok(NULL,":")) {
         if (*filename != '/') {
           strcpy(pathName, GetCurrentDir());
@@ -449,7 +444,7 @@ int AddTagsFile(const char *tagSpec, int file_type)
             added = 0;
             continue;
         }
-        t = (tagFile *) malloc(sizeof(tagFile));
+        t = (tagFile *) NEditMalloc(sizeof(tagFile));
         t->filename = STRSAVE(pathName);
         t->loaded = 0;
         t->date = statbuf.st_mtime;
@@ -458,7 +453,7 @@ int AddTagsFile(const char *tagSpec, int file_type)
         t->refcount = 1;
         FileList = setFileListHead(t, file_type );
     }
-    free(tmptagSpec);
+    NEditFree(tmptagSpec);
     updateMenuItems();
     if (added)
         return TRUE;
@@ -492,8 +487,7 @@ int DeleteTagsFile(const char *tagSpec, int file_type, Boolean force_unload)
     else
         FileList = TipsFileList;
 
-    tmptagSpec = (char *) malloc(strlen(tagSpec)+1);
-    strcpy(tmptagSpec, tagSpec);
+    tmptagSpec = NEditStrdup(tagSpec);
     removed=1;
     for (filename = strtok(tmptagSpec,":"); filename; 
             filename = strtok(NULL,":")) {
@@ -517,8 +511,8 @@ int DeleteTagsFile(const char *tagSpec, int file_type, Boolean force_unload)
                 delTag(NULL,NULL,-2,NULL,-2,t->index);
             if (last) last->next = t->next;
             else FileList = setFileListHead(t->next, file_type);
-            free(t->filename);
-            free(t);
+            NEditFree(t->filename);
+            NEditFree(t);
             updateMenuItems();
             break;
         }
@@ -558,18 +552,22 @@ static void updateMenuItems(void)
 ** Scans one <line> from a ctags tags file (<index>) in tagPath.
 ** Return value: Number of tag specs added.
 */
-static int scanCTagsLine(const char *line, const char *tagPath, int index) 
+static int scanCTagsLine(char *line, const char *tagPath, int index)
 {
-    char name[MAXLINE], searchString[MAXLINE];
-    char file[MAXPATHLEN];
-    char *posTagREEnd, *posTagRENull;
-    int  nRead, pos;
+    char *name = line, *searchString = NULL;
+    char *file = NULL;
+    char *posTagREEnd = NULL, *posTagRENull = NULL;
+    int pos;
 
-    nRead = sscanf(line, "%s\t%s\t%[^\n]", name, file, searchString);
-    if (nRead != 3) 
-        return 0;
-    if ( *name == '!' )
-        return 0;
+    /* [name]\t[file]\t[searchString]\n */
+    if ((*name != '!') && (file = strchr(name, '\t')) != NULL)
+    {
+        *file++ = '\0';
+        if ((searchString = strchr(file, '\t')) != NULL)
+            *searchString++ = '\0';
+        else return 0;
+    }
+    else return 0;
 
     /* 
     ** Guess the end of searchString:
@@ -924,7 +922,7 @@ static void findDefinitionHelper(WindowInfo *window, Time time, const char *arg,
     {
         searchMode = search_type;
         XtGetSelectionValue(window->textArea, XA_PRIMARY, XA_STRING,
-                (XtSelectionCallbackProc)findDefCB, window, time);
+                findDefCB, window, time);
     }
 }
 
@@ -952,16 +950,19 @@ void FindDefCalltip(WindowInfo *window, Time time, const char *arg)
 }
 
 /* Callback function for FindDefinition */
-static void findDefCB(Widget widget, WindowInfo *window, Atom *sel,
-        Atom *type, char *value, int *length, int *format)
+static void findDefCB(Widget widget, XtPointer closure, Atom *sel,
+        Atom *type, XtPointer v, unsigned long *length, int *format)
 {
+    WindowInfo *window = closure;
+    char *value = v;
+    
     /* skip if we can't get the selection data, or it's obviously too long */
     if (*type == XT_CONVERT_FAIL || value == NULL) {
         XBell(TheDisplay, 0);
     } else {
         findDef(window, value, searchMode);
     }
-    XtFree(value);
+    NEditFree(value);
 }
 
 /* 
@@ -996,12 +997,12 @@ static void setTag(tag *t, const char *name, const char *file,
         int language, const char *searchString, int posInf, 
         const char *path)
 {
-    t->name         = rcs_strdup(name);
-    t->file         = rcs_strdup(file);
+    t->name         = RefStringDup(name);
+    t->file         = RefStringDup(file);
+    t->searchString = RefStringDup(searchString);
+    t->path         = RefStringDup(path);
     t->language     = language;
-    t->searchString = rcs_strdup(searchString);
     t->posInf       = posInf;
-    t->path         = rcs_strdup(path);
 }
 
 /*
@@ -1011,7 +1012,7 @@ static void setTag(tag *t, const char *name, const char *file,
 ** Etags search expressions are plain literals strings, which 
 ** 
 ** If in_buffer is not NULL then it is searched instead of the window buffer.
-** In this case in_buffer should be an XtMalloc allocated buffer and the
+** In this case in_buffer should be an NEditMalloc allocated buffer and the
 ** caller is responsible for freeing it.
 */
 static int fakeRegExSearch(WindowInfo *window, char *in_buffer, 
@@ -1197,7 +1198,7 @@ static int findAllMatches(WindowInfo *window, const char *string)
     }
     
     if (nMatches>1) {
-        if (!(dupTagsList = (char **) malloc(sizeof(char *) * nMatches))) {
+        if (!(dupTagsList = (char **) NEditMalloc(sizeof(char *) * nMatches))) {
             fprintf(stderr, "nedit: findAllMatches(): out of heap space!\n");
             XBell(TheDisplay, 0);
             return -1;
@@ -1221,15 +1222,15 @@ static int findAllMatches(WindowInfo *window, const char *string)
                 sprintf(temp,"%2d. %s%s",i+1,pathname,filename);
             }
 
-            if (NULL == (dupTagsList[i] = (char*) malloc(strlen(temp) + 1))) {
+            if (NULL == (dupTagsList[i] = (char*) NEditMalloc(strlen(temp) + 1))) {
                 int j;
                 fprintf(stderr, "nedit: findAllMatches(): out of heap space!\n");
 
                 /*  dupTagsList[i] is unallocated, let's free [i - 1] to [0]  */
                 for (j = i - 1; j > -1; j--) {
-                    free(dupTagsList[j]);
+                    NEditFree(dupTagsList[j]);
                 }
-                free(dupTagsList);
+                NEditFree(dupTagsList);
 
                 XBell(TheDisplay, 0);
                 return -1;
@@ -1239,8 +1240,8 @@ static int findAllMatches(WindowInfo *window, const char *string)
         }
         createSelectMenu(dialogParent, "Duplicate Tags", nMatches, dupTagsList);
         for (i=0; i<nMatches; i++)
-            free(dupTagsList[i]);
-        free(dupTagsList);
+            NEditFree(dupTagsList[i]);
+        NEditFree(dupTagsList);
         return 1;
     }
 
@@ -1343,7 +1344,7 @@ static void showMatchingCalltip( Widget parent, int i )
     /* 2. Read the target file */
     /* Allocate space for the whole contents of the file (unfortunately) */
     fileLen = statbuf.st_size;
-    fileString = XtMalloc(fileLen+1);  /* +1 = space for null */
+    fileString = (char*)NEditMalloc(fileLen+1);  /* +1 = space for null */
     if (fileString == NULL) {
         fclose(fp);
         DialogF(DF_ERR, parent, 1, "File too large",
@@ -1357,7 +1358,7 @@ static void showMatchingCalltip( Widget parent, int i )
         fclose(fp);
         DialogF(DF_ERR, parent, 1, "Error reading File", "Error reading %s",
                 "OK", tagFiles[i]);
-        XtFree(fileString);
+        NEditFree(fileString);
         return;
     }
     fileString[readLen] = 0;
@@ -1377,7 +1378,7 @@ static void showMatchingCalltip( Widget parent, int i )
             DialogF(DF_ERR, parent, 1, "Tags Error",
                     "%s\n not long enough for definition to be on line %d",
                     "OK", tagFiles[i], tagPosInf[i]);
-            XtFree(fileString);
+            NEditFree(fileString);
             return;
         }
     } else {
@@ -1387,7 +1388,7 @@ static void showMatchingCalltip( Widget parent, int i )
             DialogF(DF_WARN, parent, 1, "Tag not found",
                     "Definition for %s\nnot found in %s", "OK", tagName,
                     tagFiles[i]);
-            XtFree(fileString);
+            NEditFree(fileString);
             return;
         }
     }
@@ -1417,12 +1418,12 @@ static void showMatchingCalltip( Widget parent, int i )
     }
     /* 5. Copy the calltip to a string */
     tipLen = endPos - startPos;
-    message = XtMalloc(tipLen+1);  /* +1 = space for null */
+    message = (char*)NEditMalloc(tipLen+1);  /* +1 = space for null */
     if (message == NULL)
     {
         DialogF(DF_ERR, parent, 1, "Out of Memory",
                 "Can't allocate memory for calltip message", "OK");
-        XtFree(fileString);
+        NEditFree(fileString);
         return;
     }
     strncpy( message, &fileString[startPos], tipLen );
@@ -1430,8 +1431,8 @@ static void showMatchingCalltip( Widget parent, int i )
     
     /* 6. Display it */
     tagsShowCalltip( WidgetToWindow(parent), message );
-    XtFree(message);
-    XtFree(fileString);
+    NEditFree(message);
+    NEditFree(fileString);
 }
 
 /*  Open a new (or existing) editor window to the location specified in
@@ -1497,7 +1498,7 @@ static Widget createSelectMenu(Widget parent, char *label, int nArgs,
     int ac;
     Arg csdargs[20];
     
-    list = (XmStringTable) XtMalloc(nArgs * sizeof(XmString *));
+    list = (XmStringTable) NEditMalloc(nArgs * sizeof(XmString *));
     for (i=0; i<nArgs; i++)
         list[i] = XmStringCreateSimple(args[i]);
     sprintf(tmpStr,"Select File With TAG: %s",tagName);
@@ -1518,7 +1519,7 @@ static Widget createSelectMenu(Widget parent, char *label, int nArgs,
     AddMotifCloseCallback(XtParent(menu), findAllCloseCB, NULL);
     for (i=0; i<nArgs; i++)
         XmStringFree(list[i]);
-    XtFree((char *)list);
+    NEditFree(list);
     XmStringFree(popupTitle);
     ManageDialogCenteredOnPointer(menu);
     return menu;
@@ -1526,172 +1527,6 @@ static Widget createSelectMenu(Widget parent, char *label, int nArgs,
 
 
 
-/*--------------------------------------------------------------------------
-
-   Reference-counted string hack; SJT 4/2000
-
-   This stuff isn't specific to tags, so it should be in it's own file.
-   However, I'm leaving it in here for now to reduce the diffs.
-   
-   This could really benefit from using a real hash table.
-*/
-
-#define RCS_SIZE 10000
-
-struct rcs;
-
-struct rcs_stats
-{
-    int talloc, tshar, tgiveup, tbytes, tbyteshared;
-};
-
-struct rcs
-{
-    struct rcs *next;
-    char       *string;
-    int         usage;
-};
-
-static struct rcs       *Rcs[RCS_SIZE];
-static struct rcs_stats  RcsStats;
-
-/*
-** Take a normal string, create a shared string from it if need be,
-** and return pointer to that shared string.
-**
-** Returned strings are const because they are shared.  Do not modify them!
-*/
-
-static const char *rcs_strdup(const char *str)
-{
-    int bucket;
-    size_t len;
-    struct rcs *rp;
-    struct rcs *prev = NULL;
-  
-    char *newstr = NULL;
-    
-    if (str == NULL)
-        return NULL;
-        
-    bucket = hashAddr(str) % RCS_SIZE;
-    len = strlen(str);
-    
-    RcsStats.talloc++;
-
-#if 0  
-    /* Don't share if it won't save space.
-    
-       Doesn't save anything - if we have lots of small-size objects,
-       it's beneifical to share them.  We don't know until we make a full
-       count.  My tests show that it's better to leave this out.  */
-    if (len <= sizeof(struct rcs))
-    {
-        new_str = strdup(str); /* GET RID OF strdup() IF EVER ENABLED (not ANSI) */ 
-        RcsStats.tgiveup++;
-        return;
-    }
-#endif
-
-    /* Find it in hash */
-    for (rp = Rcs[bucket]; rp; rp = rp->next)
-    {
-        if (!strcmp(str, rp->string))
-            break;
-        prev = rp;
-    }
-
-    if (rp)  /* It exists, return it and bump ref ct */
-    {
-        rp->usage++;
-        newstr = rp->string;
-
-        RcsStats.tshar++;
-        RcsStats.tbyteshared += len;
-    }
-    else     /* Doesn't exist, conjure up a new one. */
-    {
-        struct rcs* newrcs;
-        if (NULL == (newrcs = (struct rcs*) malloc(sizeof(struct rcs)))) {
-            /*  Not much to fall back to here.  */
-            fprintf(stderr, "nedit: rcs_strdup(): out of heap space!\n");
-            XBell(TheDisplay, 0);
-            exit(1);
-        }
-
-        if (NULL == (newrcs->string = (char*) malloc(len + 1))) {
-            /*  Not much to fall back to here.  */
-            fprintf(stderr, "nedit: rcs_strdup(): out of heap space!\n");
-            XBell(TheDisplay, 0);
-            exit(1);
-        }
-        strcpy(newrcs->string, str);
-        newrcs->usage = 1;
-        newrcs->next = NULL;
-
-        if (Rcs[bucket])
-            prev->next = newrcs;
-        else
-            Rcs[bucket] = newrcs;
-            
-        newstr = newrcs->string;
-    }
-
-    RcsStats.tbytes += len;
-    return newstr;
-}
-
-/*
-** Decrease the reference count on a shared string.  When the reference
-** count reaches zero, free the master string.
-*/
-
-static void rcs_free(const char *rcs_str)
-{
-    int bucket;
-    struct rcs *rp;
-    struct rcs *prev = NULL;
-
-    if (rcs_str == NULL)
-        return;
-        
-    bucket = hashAddr(rcs_str) % RCS_SIZE;
-
-    /* find it in hash */
-    for (rp = Rcs[bucket]; rp; rp = rp->next)
-    {
-        if (rcs_str == rp->string)
-            break;
-        prev = rp;
-    }
-
-    if (rp)  /* It's a shared string, decrease ref count */
-    {
-        rp->usage--;
-        
-        if (rp->usage < 0) /* D'OH! */
-        {
-            fprintf(stderr, "NEdit: internal error deallocating shared string.");
-            return;
-        }
-
-        if (rp->usage == 0)  /* Last one- free the storage */
-        {
-            free(rp->string);
-            if (prev)
-                prev->next = rp->next;
-            else
-                Rcs[bucket] = rp->next;
-            free(rp);
-        }
-    }
-    else    /* Doesn't appear to be a shared string */
-    {
-        fprintf(stderr, "NEdit: attempt to free a non-shared string.");
-        return;
-    }
-}
-
 /********************************************************************
  *           Functions for loading Calltips files                   *
  ********************************************************************/
@@ -1826,12 +1661,12 @@ static int nextTFBlock(FILE *fp, char *header, char **body, int *blkLine,
             return TF_ERROR;
         }
         /* Make space for the filenames/alias sources */
-        *body = (char *)malloc(incLen+1);
+        *body = (char *)NEditMalloc(incLen+1);
         if (!*body) 
             return TF_ERROR;
         *body[0]=0;
         if (fseek(fp, incPos, SEEK_SET) != 0) {
-            free (*body);
+            NEditFree(*body);
             return TF_ERROR;
         }
         /* Read all the lines in the block */
@@ -1839,7 +1674,7 @@ static int nextTFBlock(FILE *fp, char *header, char **body, int *blkLine,
         for (i=0; i<incLines; i++) {
             status = fgets(line, MAXLINE, fp);
             if (!status) {
-                free (*body);
+                NEditFree(*body);
                 return TF_ERROR_EOF;
             }
             rstrip(line,line);
@@ -1932,12 +1767,12 @@ static tf_alias *new_alias(const char *dest, char *sources) {
     
     /* fprintf(stderr, "new_alias: %s <- %s\n", dest, sources); */
     /* Allocate the alias */
-    alias = (tf_alias *)malloc( sizeof(tf_alias) );
+    alias = (tf_alias *)NEditMalloc( sizeof(tf_alias) );
     if(!alias) 
         return NULL;
 
     /* Fill it in */
-    alias->dest = (char*)malloc( strlen(dest)+1 );
+    alias->dest = (char*)NEditMalloc( strlen(dest)+1 );
     if(!(alias->dest))
         return NULL;
     strcpy( alias->dest, dest );
@@ -1950,9 +1785,9 @@ static void free_alias_list(tf_alias *alias) {
     tf_alias *tmp_alias;
     while(alias) {
         tmp_alias = alias->next;
-        free(alias->dest);
-        free(alias->sources);
-        free(alias);
+        NEditFree(alias->dest);
+        NEditFree(alias->sources);
+        NEditFree(alias);
         alias = tmp_alias;
     }
 }
@@ -1983,6 +1818,7 @@ static int loadTipsFile(const char *tipsFile, int index, int recLevel)
 #ifndef VMS
     /* Allow ~ in Unix filenames */
     strncpy(tipPath, tipsFile, MAXPATHLEN);    /* ExpandTilde is destructive */
+    tipPath[MAXPATHLEN - 1] = '\0';
     ExpandTilde(tipPath);
     if(!ResolvePath(tipPath, resolvedTipsFile))
         return 0;
@@ -2015,7 +1851,7 @@ static int loadTipsFile(const char *tipsFile, int index, int recLevel)
                     regex metacharacters that might appear in the string */
                 nTipsAdded += addTag(header, resolvedTipsFile, langMode, "", 
                         blkLine, tipPath, index);
-                free( body );
+                NEditFree( body );
                 break;
             case TF_INCLUDE:
                 /* nextTFBlock returns a colon-separated list of tips files
@@ -2027,7 +1863,7 @@ static int loadTipsFile(const char *tipsFile, int index, int recLevel)
                         tipIncFile); */
                     nTipsAdded += loadTipsFile( tipIncFile, index, recLevel+1);
                 }
-                free( body );
+                NEditFree( body );
                 break;
             case TF_LANGUAGE:
                 /* Switch to the new language mode if it's valid, else ignore
@@ -2058,6 +1894,7 @@ static int loadTipsFile(const char *tipsFile, int index, int recLevel)
                             resolvedTipsFile);
                     /* Deallocate any allocated aliases */
                     free_alias_list(tmp_alias);
+                    fclose(fp);
                     return 0;
                 }
                 /* Add it to the list */
@@ -2086,5 +1923,7 @@ static int loadTipsFile(const char *tipsFile, int index, int recLevel)
         tmp_alias = tmp_alias->next;
     }
     free_alias_list(aliases);
+    fclose(fp);
+    
     return nTipsAdded;
 }
