@@ -1,4 +1,3 @@
-/* $Id: textBuf.h,v 1.16 2004/07/21 11:32:05 yooden Exp $ */
 /*******************************************************************************
 *                                                                              *
 * textBuf.h -- Nirvana Editor Text Buffer Header File                          *
@@ -8,13 +7,13 @@
 * This is free software; you can redistribute it and/or modify it under the    *
 * terms of the GNU General Public License as published by the Free Software    *
 * Foundation; either version 2 of the License, or (at your option) any later   *
-* version. In addition, you may distribute version of this program linked to   *
+* version. In addition, you may distribute versions of this program linked to  *
 * Motif or Open Motif. See README for details.                                 *
 *                                                                              *
 * This software is distributed in the hope that it will be useful, but WITHOUT *
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or        *
-* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License *
-* for more details.                                                            *
+* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for    *
+* more details.                                                                *
 *                                                                              *
 * You should have received a copy of the GNU General Public License along with *
 * software; if not, write to the Free Software Foundation, Inc., 59 Temple     *
@@ -49,7 +48,7 @@ typedef struct {
 } selection;
 
 typedef void (*bufModifyCallbackProc)(int pos, int nInserted, int nDeleted,
-	int nRestyled, char *deletedText, void *cbArg);
+	int nRestyled, const char *deletedText, void *cbArg);
 typedef void (*bufPreDeleteCallbackProc)(int pos, int nDeleted, void *cbArg);
 
 typedef struct _textBuffer {
@@ -88,9 +87,10 @@ textBuffer *BufCreate(void);
 textBuffer *BufCreatePreallocated(int requestedSize);
 void BufFree(textBuffer *buf);
 char *BufGetAll(textBuffer *buf);
+const char *BufAsString(textBuffer *buf);
 void BufSetAll(textBuffer *buf, const char *text);
-char *BufGetRange(textBuffer *buf, int start, int end);
-char BufGetCharacter(textBuffer *buf, int pos);
+char* BufGetRange(const textBuffer* buf, int start, int end);
+char BufGetCharacter(const textBuffer* buf, int pos);
 char *BufGetTextInRect(textBuffer *buf, int start, int end,
 	int rectStart, int rectEnd);
 void BufInsert(textBuffer *buf, int pos, const char *text);
@@ -137,7 +137,6 @@ void BufRectHighlight(textBuffer *buf, int start, int end,
         int rectStart, int rectEnd);
 int BufGetHighlightPos(textBuffer *buf, int *start, int *end,
         int *isRect, int *rectStart, int *rectEnd);
-char *BufGetHighlightText(textBuffer *buf);
 void BufAddModifyCB(textBuffer *buf, bufModifyCallbackProc bufModifiedCB,
 	void *cbArg);
 void BufAddHighPriorityModifyCB(textBuffer *buf, bufModifyCallbackProc bufModifiedCB,
@@ -148,17 +147,19 @@ void BufAddPreDeleteCB(textBuffer *buf, bufPreDeleteCallbackProc bufPreDeleteCB,
 	void *cbArg);
 void BufRemovePreDeleteCB(textBuffer *buf, bufPreDeleteCallbackProc 
 	bufPreDeleteCB,	void *cbArg);
-char *BufGetLineText(textBuffer *buf, int pos);
 int BufStartOfLine(textBuffer *buf, int pos);
 int BufEndOfLine(textBuffer *buf, int pos);
-int BufGetExpandedChar(textBuffer *buf, int pos, int indent, char *outStr);
+int BufGetExpandedChar(const textBuffer* buf, int pos, int indent,
+        char* outStr);
 int BufExpandCharacter(char c, int indent, char *outStr, int tabDist,
 	char nullSubsChar);
 int BufCharWidth(char c, int indent, int tabDist, char nullSubsChar);
-int BufCountDispChars(textBuffer *buf, int lineStartPos, int targetPos);
+int BufCountDispChars(const textBuffer* buf, int lineStartPos,
+        int targetPos);
 int BufCountForwardDispChars(textBuffer *buf, int lineStartPos, int nChars);
 int BufCountLines(textBuffer *buf, int startPos, int endPos);
-int BufCountForwardNLines(textBuffer *buf, int startPos, int nLines);
+int BufCountForwardNLines(const textBuffer* buf, int startPos,
+        unsigned nLines);
 int BufCountBackwardNLines(textBuffer *buf, int startPos, int nLines);
 int BufSearchForward(textBuffer *buf, int startPos, const char *searchChars,
 	int *foundPos);
