@@ -1,4 +1,28 @@
-/* $Id: textDisp.h,v 1.23.2.1 2003/08/01 01:26:42 n8gray Exp $ */
+/*******************************************************************************
+*                                                                              *
+* textDisp.h -- Nirvana Editor Text Diplay Header File                         *
+*                                                                              *
+* Copyright 2003 The NEdit Developers                                          *
+*                                                                              *
+* This is free software; you can redistribute it and/or modify it under the    *
+* terms of the GNU General Public License as published by the Free Software    *
+* Foundation; either version 2 of the License, or (at your option) any later   *
+* version. In addition, you may distribute versions of this program linked to  *
+* Motif or Open Motif. See README for details.                                 *
+*                                                                              *
+* This software is distributed in the hope that it will be useful, but WITHOUT *
+* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or        *
+* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for    *
+* more details.                                                                *
+*                                                                              *
+* You should have received a copy of the GNU General Public License along with *
+* software; if not, write to the Free Software Foundation, Inc., 59 Temple     *
+* Place, Suite 330, Boston, MA  02111-1307 USA                                 *
+*                                                                              *
+* Nirvana Text Editor                                                          *
+* July 31, 2001                                                                *
+*                                                                              *
+*******************************************************************************/
 
 #ifndef NEDIT_TEXTDISP_H_INCLUDED
 #define NEDIT_TEXTDISP_H_INCLUDED
@@ -148,7 +172,6 @@ textDisp *TextDCreate(Widget widget, Widget hScrollBar, Widget vScrollBar,
         Pixel calltipFGPixel, Pixel calltipBGPixel);
 void TextDFree(textDisp *textD);
 void TextDSetBuffer(textDisp *textD, textBuffer *buffer);
-textBuffer *TextDGetBuffer(textDisp *textD);
 void TextDAttachHighlightData(textDisp *textD, textBuffer *styleBuffer,
     	styleTableEntry *styleTable, int nStyles, char unfinishedStyle,
     	unfinishedStyleCBProc unfinishedHighlightCB, void *cbArg);
@@ -161,7 +184,6 @@ int TextDMaxFontWidth(textDisp *textD, Boolean considerStyles);
 void TextDResize(textDisp *textD, int width, int height);
 void TextDRedisplayRect(textDisp *textD, int left, int top, int width,
 	int height);
-void TextDRedisplayRange(textDisp *textD, int start, int end);
 void TextDSetScroll(textDisp *textD, int topLineNum, int horizOffset);
 void TextDGetScroll(textDisp *textD, int *topLineNum, int *horizOffset);
 void TextDInsert(textDisp *textD, char *text);
@@ -187,10 +209,11 @@ void TextDBlankCursor(textDisp *textD);
 void TextDUnblankCursor(textDisp *textD);
 void TextDSetCursorStyle(textDisp *textD, int style);
 void TextDSetWrapMode(textDisp *textD, int wrap, int wrapMargin);
-int TextDEndOfLine(textDisp *textD, int pos, int startPosIsLineStart);
-int TextDStartOfLine(textDisp *textD, int pos);
-int TextDCountForwardNLines(textDisp *textD, int startPos, int nLines,
-    	int startPosIsLineStart);
+int TextDEndOfLine(const textDisp* textD, int pos,
+    Boolean startPosIsLineStart);
+int TextDStartOfLine(const textDisp* textD, int pos);
+int TextDCountForwardNLines(const textDisp* textD, int startPos,
+        unsigned nLines, Boolean startPosIsLineStart);
 int TextDCountBackwardNLines(textDisp *textD, int startPos, int nLines);
 int TextDCountLines(textDisp *textD, int startPos, int endPos,
     	int startPosIsLineStart);
