@@ -1,4 +1,3 @@
-/* $Id: userCmds.h,v 1.7 2004/07/21 11:32:06 yooden Exp $ */
 /*******************************************************************************
 *                                                                              *
 * userCmds.h -- Nirvana Editor user commands header file                       *
@@ -8,13 +7,13 @@
 * This is free software; you can redistribute it and/or modify it under the    *
 * terms of the GNU General Public License as published by the Free Software    *
 * Foundation; either version 2 of the License, or (at your option) any later   *
-* version. In addition, you may distribute version of this program linked to   *
+* version. In addition, you may distribute versions of this program linked to  *
 * Motif or Open Motif. See README for details.                                 *
 *                                                                              *
 * This software is distributed in the hope that it will be useful, but WITHOUT *
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or        *
-* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License *
-* for more details.                                                            *
+* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for    *
+* more details.                                                                *
 *                                                                              *
 * You should have received a copy of the GNU General Public License along with *
 * software; if not, write to the Free Software Foundation, Inc., 59 Temple     *
@@ -48,10 +47,11 @@ void SetBGMenuUndoSensitivity(WindowInfo *window, int sensitive);
 void SetBGMenuRedoSensitivity(WindowInfo *window, int sensitive);
 void DimSelectionDepUserMenuItems(WindowInfo *window, int sensitive);
 void DimPasteReplayBtns(int sensitive);
-UserMenuCache *CreateUserMenuCache();
+UserMenuCache *CreateUserMenuCache(void);
 void FreeUserMenuCache(UserMenuCache *cache);
 void InitUserBGMenuCache(UserBGMenuCache *cache);
 void FreeUserBGMenuCache(UserBGMenuCache *cache);
-void SetupUserMenuInfo();
+void SetupUserMenuInfo(void);
+void UpdateUserMenuInfo(void);
 
 #endif /* NEDIT_USERCMDS_H_INCLUDED */
