@@ -1,4 +1,3 @@
-static const char CVSID[] = "$Id: getfiles.c,v 1.30 2004/08/01 10:06:12 yooden Exp $";
 /*******************************************************************************
 *                                                                              *
 * Getfiles.c -- File Interface Routines                                        *
@@ -51,6 +50,7 @@ static const char CVSID[] = "$Id: getfiles.c,v 1.30 2004/08/01 10:06:12 yooden E
 #include "getfiles.h"
 #include "fileUtils.h"
 #include "misc.h"
+#include "nedit_malloc.h"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -73,12 +73,13 @@ static const char CVSID[] = "$Id: getfiles.c,v 1.30 2004/08/01 10:06:12 yooden E
 
 #include <X11/keysym.h>
 #include <Xm/Xm.h>
-#include <Xm/PushBG.h>
 #include <Xm/FileSB.h>
 #include <Xm/Form.h>
-#include <Xm/Text.h>
-#include <Xm/MessageB.h>
 #include <Xm/List.h>
+#include <Xm/MessageB.h>
+#include <Xm/PushBG.h>
+#include <Xm/Text.h>
+#include <Xm/TextF.h>
 
 #ifdef HAVE_DEBUG_H
 #include "../debug.h"
@@ -245,7 +246,47 @@ static Widget ErrorDialog;		/* Dialog widget for error msgs	   */
 static int ErrorDone;			/* Flag to mark dialog completed   */
 static void (*OrigDirSearchProc)();	/* Built in Motif directory search */
 static void (*OrigFileSearchProc)();	/* Built in Motif file search proc */
-		
+
+/* 
+ * Do the hard work of setting up a file selection dialog
+ */
+Widget getFilenameHelper(Widget parent, char *promptString, char *filename, 
+        int existing) 
+{
+    int       n;                      /* number of arguments               */
+    Arg	      args[MAX_ARGS];	      /* arg list	                   */
+    Widget    fileSB;	              /* widget file select box 	   */
+    XmString  titleString;	      /* compound string for dialog title  */
+
+    n = 0;
+    titleString = XmStringCreateSimple(promptString);
+    XtSetArg(args[n], XmNdialogStyle, XmDIALOG_FULL_APPLICATION_MODAL); n++;
+    XtSetArg(args[n], XmNdialogTitle, titleString); n++;
+    fileSB = CreateFileSelectionDialog(parent,"FileSelect",args,n);
+    XmStringFree(titleString);
+#ifndef SGI_CUSTOM
+    if (existing && RemoveRedundantTextField)
+        XtUnmanageChild(XmFileSelectionBoxGetChild(fileSB, XmDIALOG_TEXT)); 
+    XtUnmanageChild(XmFileSelectionBoxGetChild(fileSB, XmDIALOG_SELECTION_LABEL));
+
+    XtVaSetValues(XmFileSelectionBoxGetChild(fileSB, XmDIALOG_FILTER_LABEL),
+            XmNmnemonic, 'l',
+            XmNuserData, XmFileSelectionBoxGetChild(fileSB, XmDIALOG_FILTER_TEXT),
+            NULL);
+    XtVaSetValues(XmFileSelectionBoxGetChild(fileSB, XmDIALOG_DIR_LIST_LABEL),
+            XmNmnemonic, 'D',
+            XmNuserData, XmFileSelectionBoxGetChild(fileSB, XmDIALOG_DIR_LIST),
+            NULL);
+    XtVaSetValues(XmFileSelectionBoxGetChild(fileSB, XmDIALOG_LIST_LABEL),
+            XmNmnemonic, promptString[strspn(promptString, "lD")],
+            XmNuserData, XmFileSelectionBoxGetChild(fileSB, XmDIALOG_LIST),
+            NULL);
+    AddDialogMnemonicHandler(fileSB, FALSE);
+    RemapDeleteKey(XmFileSelectionBoxGetChild(fileSB, XmDIALOG_FILTER_TEXT));
+    RemapDeleteKey(XmFileSelectionBoxGetChild(fileSB, XmDIALOG_TEXT));
+#endif
+    return fileSB;
+}
 
 /*  GetExistingFilename				  	                   */
 /*									   */
@@ -269,43 +310,26 @@ static void (*OrigFileSearchProc)();	/* Built in Motif file search proc */
 /*  Returns:	GFN_OK	      - file was selected and OK button pressed	   */
 /*		GFN_CANCEL    - Cancel button pressed and no returned file */
 /*									   */
-int GetExistingFilename (Widget parent, char *promptString, char *filename) 
+int GetExistingFilename(Widget parent, char *promptString, char *filename) 
 {
-    int       n;                      /* number of arguments               */
-    Arg	      args[MAX_ARGS];	      /* arg list	                   */
-    Widget    existFileSB;	      /* widget file select box 	   */
-    XmString  titleString;	      /* compound string for dialog title  */
-
-    n = 0;
-    titleString = XmStringCreateSimple(promptString);
-    XtSetArg(args[n], XmNdialogStyle, XmDIALOG_FULL_APPLICATION_MODAL); n++;
-    XtSetArg(args[n], XmNdialogTitle, titleString); n++;
-    existFileSB = CreateFileSelectionDialog(parent,"FileSelect",args,n);
-    XmStringFree(titleString);
-#ifndef SGI_CUSTOM
-    if (RemoveRedundantTextField)
-        XtUnmanageChild(XmFileSelectionBoxGetChild(existFileSB, XmDIALOG_TEXT)); 
-    XtUnmanageChild(XmFileSelectionBoxGetChild(existFileSB, XmDIALOG_SELECTION_LABEL));
-
-    XtVaSetValues(XmFileSelectionBoxGetChild(existFileSB, XmDIALOG_FILTER_LABEL),
-            XmNmnemonic, 'l',
-            XmNuserData, XmFileSelectionBoxGetChild(existFileSB, XmDIALOG_FILTER_TEXT),
-            NULL);
-    XtVaSetValues(XmFileSelectionBoxGetChild(existFileSB, XmDIALOG_DIR_LIST_LABEL),
-            XmNmnemonic, 'D',
-            XmNuserData, XmFileSelectionBoxGetChild(existFileSB, XmDIALOG_DIR_LIST),
-            NULL);
-    XtVaSetValues(XmFileSelectionBoxGetChild(existFileSB, XmDIALOG_LIST_LABEL),
-            XmNmnemonic, promptString[strspn(promptString, "lD")],
-            XmNuserData, XmFileSelectionBoxGetChild(existFileSB, XmDIALOG_LIST),
-            NULL);
-    AddDialogMnemonicHandler(existFileSB, FALSE);
-    RemapDeleteKey(XmFileSelectionBoxGetChild(existFileSB, XmDIALOG_FILTER_TEXT));
-    RemapDeleteKey(XmFileSelectionBoxGetChild(existFileSB, XmDIALOG_TEXT));
-#endif
+    Widget existFileSB = getFilenameHelper(parent, promptString, filename, 
+            True);
     return HandleCustomExistFileSB(existFileSB, filename);
 }
 
+/* GetNewFilename
+ *
+ * Same as GetExistingFilename but pick a new file instead of an existing one.
+ * In this case the text area of the FSB is *not* unmanaged, so the user can
+ * enter a new filename.
+ */
+int GetNewFilename(Widget parent, char *promptString, char *filename,
+        char *defaultName)
+{
+    Widget fileSB = getFilenameHelper(parent, promptString, filename, False);
+    return HandleCustomNewFileSB(fileSB, filename, defaultName);
+}
+
 /*
 ** HandleCustomExistFileSB
 **
@@ -424,10 +448,10 @@ int HandleCustomExistFileSB(Widget existFileSB, char *filename)
    	    XmStringGetLtoR(cDir, XmSTRING_DEFAULT_CHARSET, &dirString);
 	    strcpy(filename, dirString);
 	    strcat(filename, fileString);
-  	    XtFree(dirString);
+  	    NEditFree(dirString);
 	}
 	XmStringFree(cFileString);
-	XtFree(fileString);
+	NEditFree(fileString);
     }
     /* Destroy the dialog _shell_ iso. the dialog. Normally, this shouldn't
        be necessary as the shell is destroyed automatically when the dialog
@@ -487,10 +511,6 @@ int HandleCustomNewFileSB(Widget newFileSB, char *filename, char *defaultName)
     createErrorDialog(newFileSB);
     XtAddCallback(newFileSB, XmNhelpCallback, (XtCallbackProc)newHelpCB, 
     	    (char *)help);
-    if (defaultName != NULL) {
-	Widget nameField = XmFileSelectionBoxGetChild(newFileSB, XmDIALOG_TEXT);
-	XmTextInsert(nameField, XmTextGetLastPosition(nameField), defaultName);
-    }
 #if XmVersion >= 1002
 #ifndef SGI_CUSTOM
     XtVaSetValues(newFileSB, XmNinitialFocus, 
@@ -530,6 +550,26 @@ int HandleCustomNewFileSB(Widget newFileSB, char *filename, char *defaultName)
     sortWidgetList(XmFileSelectionBoxGetChild(newFileSB, XmDIALOG_DIR_LIST));
     sortWidgetList(XmFileSelectionBoxGetChild(newFileSB, XmDIALOG_LIST));
 #endif /* SGI_CUSTOM */
+
+    /* Delay the setting of the default name till after the replacement of 
+       the search procedures. Otherwise the field is cleared again by certain
+       *tif implementations */
+    if (defaultName != NULL) {
+	Widget nameField = XmFileSelectionBoxGetChild(newFileSB, XmDIALOG_TEXT);
+#ifdef LESSTIF_VERSION
+        /* Workaround for Lesstif bug (0.93.94 and possibly other versions): 
+           if a proportional font is used for the text field and text is
+           inserted while the dialog is managed, Lesstif crashes because it
+           tries to access a non-existing selection. By creating a temporary 
+           dummy selection, the crash is avoided. */
+        XmTextFieldSetSelection(nameField, 0, 1, CurrentTime);
+	XmTextInsert(nameField, XmTextGetLastPosition(nameField), defaultName);
+        XmTextFieldSetSelection(nameField, 0, 0, CurrentTime);
+#else
+	XmTextInsert(nameField, XmTextGetLastPosition(nameField), defaultName);
+#endif
+    }
+
     while (!done_with_dialog)
         XtAppProcessEvent (XtWidgetToApplicationContext(newFileSB), XtIMAll);
 
@@ -559,10 +599,10 @@ int HandleCustomNewFileSB(Widget newFileSB, char *filename, char *defaultName)
    	    XmStringGetLtoR(cDir, XmSTRING_DEFAULT_CHARSET, &dirString);
 	    strcpy(filename, dirString);
 	    strcat(filename, fileString);
-  	    XtFree(dirString);
+  	    NEditFree(dirString);
 	}
 	XmStringFree(cFileString);
-	XtFree(fileString);
+	NEditFree(fileString);
     }
     XtDestroyWidget(newFileSB);
     return SelectResult;
@@ -572,7 +612,7 @@ int HandleCustomNewFileSB(Widget newFileSB, char *filename, char *defaultName)
 ** Return current default directory used by GetExistingFilename.
 ** Can return NULL if no default directory has been set (meaning
 ** use the application's current working directory) String must
-** be freed by the caller using XtFree.
+** be freed by the caller using NEditFree.
 */
 char *GetFileDialogDefaultDirectory(void)
 {
@@ -588,7 +628,7 @@ char *GetFileDialogDefaultDirectory(void)
 ** Return current default match pattern used by GetExistingFilename.
 ** Can return NULL if no default pattern has been set (meaning use
 ** a pattern matching all files in the directory) String must be
-** freed by the caller using XtFree.
+** freed by the caller using NEditFree.
 */
 char *GetFileDialogDefaultPattern(void)
 {
@@ -757,7 +797,7 @@ static void newFileOKCB(Widget	w, Boolean *client_data,
     length = strlen(filename);
     if (length == 0 || filename[length-1] == '/') {
     	doErrorDialog("Please supply a name for the file", NULL);
-	XtFree(filename);
+	NEditFree(filename);
     	return;
     }
 
@@ -770,7 +810,7 @@ static void newFileOKCB(Widget	w, Boolean *client_data,
         close(fd);
 	if (buf.st_mode & S_IFDIR) {
             doErrorDialog("Error: %s is a directory", filename);
-	    XtFree(filename);
+	    NEditFree(filename);
 	    return;
 	}
         response = doYesNoDialog(filename);
@@ -778,7 +818,7 @@ static void newFileOKCB(Widget	w, Boolean *client_data,
 	if (response) {
             if (access(filename, 2) != 0) { /* have write/delete access? */
 		doErrorDialog("Error: can't overwrite %s ", filename);
-		XtFree(filename);
+		NEditFree(filename);
 		return;
 	    }
 	} else {
@@ -790,14 +830,14 @@ static void newFileOKCB(Widget	w, Boolean *client_data,
     } else {
 	if ((fd = creat(filename, PERMS)) == -1) {
             doErrorDialog("Error: can't create %s ", filename);
-	    XtFree(filename);
+	    NEditFree(filename);
 	    return;
 	} else {
 	    close(fd);
             remove(filename);
 	}
     }
-    XtFree(filename);
+    NEditFree(filename);
     *client_data = True;			    /* done with dialog */
 }
 
@@ -825,15 +865,15 @@ static void existOkCB(Widget w, Boolean * client_data,
     length = strlen(filename);
     if (length == 0 || filename[length-1] == '/') {
     	doErrorDialog("Please select a file to open", NULL);
-    	XtFree(filename);
+    	NEditFree(filename);
     	return;
     } else    if ((fd = open(filename, O_RDONLY,0))  == -1) {
     	doErrorDialog("Error: can't open %s ", filename);
-    	XtFree(filename);
+    	NEditFree(filename);
         return;
     } else
     	close(fd);
-    XtFree(filename);
+    NEditFree(filename);
     	
     *client_data = True;		/* done with dialog		*/
 }
@@ -985,10 +1025,10 @@ static void listCharEH(Widget w, XtPointer callData, XEvent *event,
     for (i=0; i<nItems; i++) {
     	XmStringGetLtoR(items[i], XmSTRING_DEFAULT_CHARSET, &itemString);
     	if (ParseFilename(itemString, name, path) != 0) {
-	   XtFree(itemString);
+	   NEditFree(itemString);
 	   return;
 	}
-	XtFree(itemString);
+	NEditFree(itemString);
     	cmp = strncmp(name, keystrokes, nKeystrokes);
     	if (cmp == 0) {
     	    selectPos = i+1;
@@ -1068,15 +1108,19 @@ static void sortWidgetList(Widget listWidget)
     XmString *items, *sortedItems;
     int nItems, i;
     
+    /* OpenMotif 2.3 will crash if we try to replace the items, when they
+       are selected. This function is only called when we refresh the
+       contents anyway. */
+    XmListDeselectAllItems(listWidget);
     XtVaGetValues(listWidget, XmNitems, &items, XmNitemCount, &nItems, NULL);
-    sortedItems = (XmString *)XtMalloc(sizeof(XmString) * nItems);
+    sortedItems = (XmString *)NEditMalloc(sizeof(XmString) * nItems);
     for (i=0; i<nItems; i++)
     	sortedItems[i] = XmStringCopy(items[i]);
     qsort(sortedItems, nItems, sizeof(XmString), compareXmStrings);
     XmListReplaceItemsPos(listWidget, sortedItems, nItems, 1);
     for (i=0; i<nItems; i++)
     	XmStringFree(sortedItems[i]);
-    XtFree((char *)sortedItems);
+    NEditFree((char *)sortedItems);
 }
 
 /*
@@ -1090,7 +1134,7 @@ static int compareXmStrings(const void *string1, const void *string2)
     XmStringGetLtoR(*(XmString *)string1, XmSTRING_DEFAULT_CHARSET, &s1);
     XmStringGetLtoR(*(XmString *)string2, XmSTRING_DEFAULT_CHARSET, &s2);
     result = strcmp(s1, s2);
-    XtFree(s1);
-    XtFree(s2);
+    NEditFree(s1);
+    NEditFree(s2);
     return result;
 }
