@@ -1,4 +1,3 @@
-static const char CVSID[] = "$Id: utils.c,v 1.27 2008/01/04 22:11:05 yooden Exp $";
 /*******************************************************************************
 *                                                                              *
 * utils.c -- miscellaneous non-GUI routines                                    *
@@ -27,6 +26,7 @@ static const char CVSID[] = "$Id: utils.c,v 1.27 2008/01/04 22:11:05 yooden Exp
 #endif
 
 #include "utils.h"
+#include "nedit_malloc.h"
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -412,7 +412,7 @@ void Push(Stack* stack, const void* value)
     }
 
     /*  Allocate memory for new value.  */
-    pushee = (stackObject*) XtMalloc(sizeof(stackObject));
+    pushee = (stackObject*) NEditMalloc(sizeof(stackObject));
 
     /*  Put pushee on top of stack.  */
     pushee->value = (void*) value;
@@ -453,7 +453,7 @@ void* Pop(Stack* stack)
     (stack->size)--;
 
     value = popee->value;
-    XtFree((char*) popee);
+    NEditFree((char*) popee);
 
     return value;
 }
@@ -471,6 +471,6 @@ void FreeStack(Stack* stack)
 
     while (NULL != (dummy = pop(progStack))) {}
 
-    XtFree((char*) stack);
+    NEditFree((char*) stack);
 }
 */
